from .qzss_dcr_definition import QzssDcrDefinition


qzss_dcx_ex1_target_area_code_en = QzssDcrDefinition(
    {
        1000: 'Hokkaido',
        1100: 'Sapporo-shi, Hokkaido',
        1101: 'Chuo-ku, Sapporo-shi',
        1102: 'Kita-ku, Sapporo-shi',
        1103: 'Higashi-ku, Sapporo-shi',
        1104: 'Shiroishi-ku, Sapporo-shi',
        1105: 'Toyohira-ku, Sapporo-shi',
        1106: 'Minami-ku, Sapporo-shi',
        1107: 'Nishi-ku, Sapporo-shi',
        1108: 'Atsubetsu-ku, Sapporo-shi',
        1109: 'Teine-ku, Sapporo-shi',
        1110: 'Kiyota-ku, Sapporo-shi',
        1202: 'Hakodate-shi, Hokkaido',
        1203: 'Otaru-shi, Hokkaido',
        1204: 'Asahikawa-shi, Hokkaido',
        1205: 'Muroran-shi, Hokkaido',
        1206: 'Kushiro-shi, Hokkaido',
        1207: 'Obihiro-shi, Hokkaido',
        1208: 'Kitami-shi, Hokkaido',
        1209: 'Yubari-shi, Hokkaido',
        1210: 'Iwamizawa-shi, Hokkaido',
        1211: 'Abashiri-shi, Hokkaido',
        1212: 'Rumoi-shi, Hokkaido',
        1213: 'Tomakomai-shi, Hokkaido',
        1214: 'Wakkanai-shi, Hokkaido',
        1215: 'Bibai-shi, Hokkaido',
        1216: 'Ashibetsu-shi, Hokkaido',
        1217: 'Ebetsu-shi, Hokkaido',
        1218: 'Akabira-shi, Hokkaido',
        1219: 'Mombetsu-shi, Hokkaido',
        1220: 'Shibetsu-shi, Hokkaido',
        1221: 'Nayoro-shi, Hokkaido',
        1222: 'Mikasa-shi, Hokkaido',
        1223: 'Nemuro-shi, Hokkaido',
        1224: 'Chitose-shi, Hokkaido',
        1225: 'Takikawa-shi, Hokkaido',
        1226: 'Sunagawa-shi, Hokkaido',
        1227: 'Utashinai-shi, Hokkaido',
        1228: 'Fukagawa-shi, Hokkaido',
        1229: 'Furano-shi, Hokkaido',
        1230: 'Noboribetsu-shi, Hokkaido',
        1231: 'Eniwa-shi, Hokkaido',
        1233: 'Date-shi, Hokkaido',
        1234: 'Kitahiroshima-shi, Hokkaido',
        1235: 'Ishikari-shi, Hokkaido',
        1236: 'Hokuto-shi, Hokkaido',
        1303: 'Tobetsu-cho, Hokkaido',
        1304: 'Shinshinotsu-mura, Hokkaido',
        1331: 'Matsumae-cho, Hokkaido',
        1332: 'Fukushima-cho, Hokkaido',
        1333: 'Shiriuchi-cho, Hokkaido',
        1334: 'Kikonai-cho, Hokkaido',
        1337: 'Nanae-cho, Hokkaido',
        1343: 'Shikabe-cho, Hokkaido',
        1345: 'Mori-machi, Hokkaido',
        1346: 'Yakumo-cho, Hokkaido',
        1347: 'Oshamambe-cho, Hokkaido',
        1361: 'Esashi-cho, Hokkaido',
        1362: 'Kaminokuni-cho, Hokkaido',
        1363: 'Assabu-cho, Hokkaido',
        1364: 'Otobe-cho, Hokkaido',
        1367: 'Okushiri-cho, Hokkaido',
        1370: 'Imakane-cho, Hokkaido',
        1371: 'Setana-cho, Hokkaido',
        1391: 'Shimamaki-mura, Hokkaido',
        1392: 'Suttsu-cho, Hokkaido',
        1393: 'Kuromatsunai-cho, Hokkaido',
        1394: 'Rankoshi-cho, Hokkaido',
        1395: 'Niseko-cho, Hokkaido',
        1396: 'Makkari-mura, Hokkaido',
        1397: 'Rusutsu-mura, Hokkaido',
        1398: 'Kimobetsu-cho, Hokkaido',
        1399: 'Kyogoku-cho, Hokkaido',
        1400: 'Kutchan-cho, Hokkaido',
        1401: 'Kyowa-cho, Hokkaido',
        1402: 'Iwanai-cho, Hokkaido',
        1403: 'Tomari-mura, Hokkaido',
        1404: 'Kamoenai-mura, Hokkaido',
        1405: 'Shakotan-cho, Hokkaido',
        1406: 'Furubira-cho, Hokkaido',
        1407: 'Niki-cho, Hokkaido',
        1408: 'Yoichi-cho, Hokkaido',
        1409: 'Akaigawa-mura, Hokkaido',
        1423: 'Namporo-cho, Hokkaido',
        1424: 'Naie-cho, Hokkaido',
        1425: 'Kamisunagawa-cho, Hokkaido',
        1427: 'Yuni-cho, Hokkaido',
        1428: 'Naganuma-cho, Hokkaido',
        1429: 'Kuriyama-cho, Hokkaido',
        1430: 'Tsukigata-cho, Hokkaido',
        1431: 'Urausu-cho, Hokkaido',
        1432: 'Shintotsukawa-cho, Hokkaido',
        1433: 'Moseushi-cho, Hokkaido',
        1434: 'Chippubetsu-cho, Hokkaido',
        1436: 'Uryu-cho, Hokkaido',
        1437: 'Hokuryu-cho, Hokkaido',
        1438: 'Numata-cho, Hokkaido',
        1452: 'Takasu-cho, Hokkaido',
        1453: 'Higashikagura-cho, Hokkaido',
        1454: 'Toma-cho, Hokkaido',
        1455: 'Pippu-cho, Hokkaido',
        1456: 'Aibetsu-cho, Hokkaido',
        1457: 'Kamikawa-cho, Hokkaido',
        1458: 'Higashikawa-cho, Hokkaido',
        1459: 'Biei-cho, Hokkaido',
        1460: 'Kamifurano-cho, Hokkaido',
        1461: 'Nakafurano-cho, Hokkaido',
        1462: 'Minamifurano-cho, Hokkaido',
        1463: 'Shimukappu-mura, Hokkaido',
        1464: 'Wassamu-cho, Hokkaido',
        1465: 'Kembuchi-cho, Hokkaido',
        1468: 'Shimokawa-cho, Hokkaido',
        1469: 'Bifuka-cho, Hokkaido',
        1470: 'Otoineppu-mura, Hokkaido',
        1471: 'Nakagawa-cho, Hokkaido',
        1472: 'Horokanai-cho, Hokkaido',
        1481: 'Mashike-cho, Hokkaido',
        1482: 'Obira-cho, Hokkaido',
        1483: 'Tomamae-cho, Hokkaido',
        1484: 'Haboro-cho, Hokkaido',
        1485: 'Shosambetsu-mura, Hokkaido',
        1486: 'Embetsu-cho, Hokkaido',
        1487: 'Teshio-cho, Hokkaido',
        1511: 'Sarufutsu-mura, Hokkaido',
        1512: 'Hamatombetsu-cho, Hokkaido',
        1513: 'Nakatombetsu-cho, Hokkaido',
        1514: 'Esashi-cho, Hokkaido',
        1516: 'Toyotomi-cho, Hokkaido',
        1517: 'Rebun-cho, Hokkaido',
        1518: 'Rishiri-cho, Hokkaido',
        1519: 'Rishirifuji-cho, Hokkaido',
        1520: 'Horonobe-cho, Hokkaido',
        1543: 'Bihoro-cho, Hokkaido',
        1544: 'Tsubetsu-cho, Hokkaido',
        1545: 'Shari-cho, Hokkaido',
        1546: 'Kiyosato-cho, Hokkaido',
        1547: 'Koshimizu-cho, Hokkaido',
        1549: 'Kunneppu-cho, Hokkaido',
        1550: 'Oketo-cho, Hokkaido',
        1552: 'Saroma-cho, Hokkaido',
        1555: 'Engaru-cho, Hokkaido',
        1559: 'Yubetsu-cho, Hokkaido',
        1560: 'Takinoue-cho, Hokkaido',
        1561: 'Okoppe-cho, Hokkaido',
        1562: 'Nishiokoppe-mura, Hokkaido',
        1563: 'Omu-cho, Hokkaido',
        1564: 'Ozora-cho, Hokkaido',
        1571: 'Toyoura-cho, Hokkaido',
        1575: 'Sobetsu-cho, Hokkaido',
        1578: 'Shiraoi-cho, Hokkaido',
        1581: 'Atsuma-cho, Hokkaido',
        1584: 'Toyako-cho, Hokkaido',
        1585: 'Abira-cho, Hokkaido',
        1586: 'Mukawa-cho, Hokkaido',
        1601: 'Hidaka-cho, Hokkaido',
        1602: 'Biratori-cho, Hokkaido',
        1604: 'Niikappu-cho, Hokkaido',
        1607: 'Urakawa-cho, Hokkaido',
        1608: 'Samani-cho, Hokkaido',
        1609: 'Erimo-cho, Hokkaido',
        1610: 'Shinhidaka-cho, Hokkaido',
        1631: 'Otofuke-cho, Hokkaido',
        1632: 'Shihoro-cho, Hokkaido',
        1633: 'Kamishihoro-cho, Hokkaido',
        1634: 'Shikaoi-cho, Hokkaido',
        1635: 'Shintoku-cho, Hokkaido',
        1636: 'Shimizu-cho, Hokkaido',
        1637: 'Memuro-cho, Hokkaido',
        1638: 'Nakasatsunai-mura, Hokkaido',
        1639: 'Sarabetsu-mura, Hokkaido',
        1641: 'Taiki-cho, Hokkaido',
        1642: 'Hiroo-cho, Hokkaido',
        1643: 'Makubetsu-cho, Hokkaido',
        1644: 'Ikeda-cho, Hokkaido',
        1645: 'Toyokoro-cho, Hokkaido',
        1646: 'Hombetsu-cho, Hokkaido',
        1647: 'Ashoro-cho, Hokkaido',
        1648: 'Rikubetsu-cho, Hokkaido',
        1649: 'Urahoro-cho, Hokkaido',
        1661: 'Kushiro-cho, Hokkaido',
        1662: 'Akkeshi-cho, Hokkaido',
        1663: 'Hamanaka-cho, Hokkaido',
        1664: 'Shibecha-cho, Hokkaido',
        1665: 'Teshikaga-cho, Hokkaido',
        1667: 'Tsurui-mura, Hokkaido',
        1668: 'Shiranuka-cho, Hokkaido',
        1691: 'Betsukai-cho, Hokkaido',
        1692: 'Nakashibetsu-cho, Hokkaido',
        1693: 'Shibetsu-cho, Hokkaido',
        1694: 'Rausu-cho, Hokkaido',
        1695: 'Shikotan-mura, Hokkaido',
        1696: 'Tomari-mura, Hokkaido',
        1697: 'Ruyabetsu-mura, Hokkaido',
        1698: 'Rubetsu-mura, Hokkaido',
        1699: 'Shana-mura, Hokkaido',
        1700: 'Shibetoro-mura, Hokkaido',
        2000: 'Aomori',
        2201: 'Aomori-shi, Aomori',
        2202: 'Hirosaki-shi, Aomori',
        2203: 'Hachinohe-shi, Aomori',
        2204: 'Kuroishi-shi, Aomori',
        2205: 'Goshogawara-shi, Aomori',
        2206: 'Towada-shi, Aomori',
        2207: 'Misawa-shi, Aomori',
        2208: 'Mutsu-shi, Aomori',
        2209: 'Tsugaru-shi, Aomori',
        2210: 'Hirakawa-shi, Aomori',
        2301: 'Hiranai-machi, Aomori',
        2303: 'Imabetsu-machi, Aomori',
        2304: 'Yomogita-mura, Aomori',
        2307: 'Sotogahama-machi, Aomori',
        2321: 'Ajigasawa-machi, Aomori',
        2323: 'Fukaura-machi, Aomori',
        2343: 'Nishimeya-mura, Aomori',
        2361: 'Fujisaki-machi, Aomori',
        2362: 'Owani-machi, Aomori',
        2367: 'Inakadate-mura, Aomori',
        2381: 'Itayanagi-machi, Aomori',
        2384: 'Tsuruta-machi, Aomori',
        2387: 'Nakadomari-machi, Aomori',
        2401: 'Noheji-machi, Aomori',
        2402: 'Shichinohe-machi, Aomori',
        2405: 'Rokunohe-machi, Aomori',
        2406: 'Yokohama-machi, Aomori',
        2408: 'Tohoku-machi, Aomori',
        2411: 'Rokkasho-mura, Aomori',
        2412: 'Oirase-cho, Aomori',
        2423: 'Oma-machi, Aomori',
        2424: 'Higashidori-mura, Aomori',
        2425: 'Kazamaura-mura, Aomori',
        2426: 'Sai-mura, Aomori',
        2441: 'Sannohe-machi, Aomori',
        2442: 'Gonohe-machi, Aomori',
        2443: 'Takko-machi, Aomori',
        2445: 'Nambu-cho, Aomori',
        2446: 'Hashikami-cho, Aomori',
        2450: 'Shingo-mura, Aomori',
        3000: 'Iwate',
        3201: 'Morioka-shi, Iwate',
        3202: 'Miyako-shi, Iwate',
        3203: 'Ofunato-shi, Iwate',
        3205: 'Hanamaki-shi, Iwate',
        3206: 'Kitakami-shi, Iwate',
        3207: 'Kuji-shi, Iwate',
        3208: 'Tono-shi, Iwate',
        3209: 'Ichinoseki-shi, Iwate',
        3210: 'Rikuzentakata-shi, Iwate',
        3211: 'Kamaishi-shi, Iwate',
        3213: 'Ninohe-shi, Iwate',
        3214: 'Hachimantai-shi, Iwate',
        3215: 'Oshu-shi, Iwate',
        3216: 'Takizawa-shi, Iwate',
        3301: 'Shizukuishi-cho, Iwate',
        3302: 'Kuzumaki-machi, Iwate',
        3303: 'Iwate-machi, Iwate',
        3321: 'Shiwa-cho, Iwate',
        3322: 'Yahaba-cho, Iwate',
        3366: 'Nishiwaga-machi, Iwate',
        3381: 'Kanegasaki-cho, Iwate',
        3402: 'Hiraizumi-cho, Iwate',
        3441: 'Sumita-cho, Iwate',
        3461: 'Otsuchi-cho, Iwate',
        3482: 'Yamada-machi, Iwate',
        3483: 'Iwaizumi-cho, Iwate',
        3484: 'Tanohata-mura, Iwate',
        3485: 'Fudai-mura, Iwate',
        3501: 'Karumai-machi, Iwate',
        3503: 'Noda-mura, Iwate',
        3506: 'Kunohe-mura, Iwate',
        3507: 'Hirono-cho, Iwate',
        3524: 'Ichinohe-machi, Iwate',
        4000: 'Miyagi',
        4100: 'Sendai-shi, Miyagi',
        4101: 'Aoba-ku, Sendai-shi',
        4102: 'Miyagino-ku, Sendai-shi',
        4103: 'Wakabayashi-ku, Sendai-shi',
        4104: 'Taihaku-ku, Sendai-shi',
        4105: 'Izumi-ku, Sendai-shi',
        4202: 'Ishinomaki-shi, Miyagi',
        4203: 'Shiogama-shi, Miyagi',
        4205: 'Kesennuma-shi, Miyagi',
        4206: 'Shiroishi-shi, Miyagi',
        4207: 'Natori-shi, Miyagi',
        4208: 'Kakuda-shi, Miyagi',
        4209: 'Tagajo-shi, Miyagi',
        4211: 'Iwanuma-shi, Miyagi',
        4212: 'Tome-shi, Miyagi',
        4213: 'Kurihara-shi, Miyagi',
        4214: 'Higashimatsushima-shi, Miyagi',
        4215: 'Osaki-shi, Miyagi',
        4216: 'Tomiya-shi, Miyagi',
        4301: 'Zao-machi, Miyagi',
        4302: 'Shichikashuku-machi, Miyagi',
        4321: 'Ogawara-machi, Miyagi',
        4322: 'Murata-machi, Miyagi',
        4323: 'Shibata-machi, Miyagi',
        4324: 'Kawasaki-machi, Miyagi',
        4341: 'Marumori-machi, Miyagi',
        4361: 'Watari-cho, Miyagi',
        4362: 'Yamamoto-cho, Miyagi',
        4401: 'Matsushima-machi, Miyagi',
        4404: 'Shichigahama-machi, Miyagi',
        4406: 'Rifu-cho, Miyagi',
        4421: 'Taiwa-cho, Miyagi',
        4422: 'Osato-cho, Miyagi',
        4424: 'Ohira-mura, Miyagi',
        4444: 'Shikama-cho, Miyagi',
        4445: 'Kami-machi, Miyagi',
        4501: 'Wakuya-cho, Miyagi',
        4505: 'Misato-machi, Miyagi',
        4581: 'Onagawa-cho, Miyagi',
        4606: 'Minamisanriku-cho, Miyagi',
        5000: 'Akita',
        5201: 'Akita-shi, Akita',
        5202: 'Noshiro-shi, Akita',
        5203: 'Yokote-shi, Akita',
        5204: 'Odate-shi, Akita',
        5206: 'Oga-shi, Akita',
        5207: 'Yuzawa-shi, Akita',
        5209: 'Kazuno-shi, Akita',
        5210: 'Yurihonjo-shi, Akita',
        5211: 'Katagami-shi, Akita',
        5212: 'Daisen-shi, Akita',
        5213: 'Kitaakita-shi, Akita',
        5214: 'Nikaho-shi, Akita',
        5215: 'Semboku-shi, Akita',
        5303: 'Kosaka-machi, Akita',
        5327: 'Kamikoani-mura, Akita',
        5346: 'Fujisato-machi, Akita',
        5348: 'Mitane-cho, Akita',
        5349: 'Happo-cho, Akita',
        5361: 'Gojome-machi, Akita',
        5363: 'Hachirogata-machi, Akita',
        5366: 'Ikawa-machi, Akita',
        5368: 'Ogata-mura, Akita',
        5434: 'Misato-cho, Akita',
        5463: 'Ugo-machi, Akita',
        5464: 'Higashinaruse-mura, Akita',
        6000: 'Yamagata',
        6201: 'Yamagata-shi, Yamagata',
        6202: 'Yonezawa-shi, Yamagata',
        6203: 'Tsuruoka-shi, Yamagata',
        6204: 'Sakata-shi, Yamagata',
        6205: 'Shinjo-shi, Yamagata',
        6206: 'Sagae-shi, Yamagata',
        6207: 'Kaminoyama-shi, Yamagata',
        6208: 'Murayama-shi, Yamagata',
        6209: 'Nagai-shi, Yamagata',
        6210: 'Tendo-shi, Yamagata',
        6211: 'Higashine-shi, Yamagata',
        6212: 'Obanazawa-shi, Yamagata',
        6213: 'Nanyo-shi, Yamagata',
        6301: 'Yamanobe-machi, Yamagata',
        6302: 'Nakayama-machi, Yamagata',
        6321: 'Kahoku-cho, Yamagata',
        6322: 'Nishikawa-machi, Yamagata',
        6323: 'Asahi-machi, Yamagata',
        6324: 'Oe-machi, Yamagata',
        6341: 'Oishida-machi, Yamagata',
        6361: 'Kaneyama-machi, Yamagata',
        6362: 'Mogami-machi, Yamagata',
        6363: 'Funagata-machi, Yamagata',
        6364: 'Mamurogawa-machi, Yamagata',
        6365: 'Okura-mura, Yamagata',
        6366: 'Sakegawa-mura, Yamagata',
        6367: 'Tozawa-mura, Yamagata',
        6381: 'Takahata-machi, Yamagata',
        6382: 'Kawanishi-machi, Yamagata',
        6401: 'Oguni-machi, Yamagata',
        6402: 'Shirataka-machi, Yamagata',
        6403: 'Iide-machi, Yamagata',
        6426: 'Mikawa-machi, Yamagata',
        6428: 'Shiyonai-machi, Yamagata',
        6461: 'Yuza-machi, Yamagata',
        7000: 'Fukushima',
        7201: 'Fukushima-shi, Fukushima',
        7202: 'Aizuwakamatsu-shi, Fukushima',
        7203: 'Koriyama-shi, Fukushima',
        7204: 'Iwaki-shi, Fukushima',
        7205: 'Shirakawa-shi, Fukushima',
        7207: 'Sukagawa-shi, Fukushima',
        7208: 'Kitakata-shi, Fukushima',
        7209: 'Soma-shi, Fukushima',
        7210: 'Nihommatsu-shi, Fukushima',
        7211: 'Tamura-shi, Fukushima',
        7212: 'Minamisoma-shi, Fukushima',
        7213: 'Date-shi, Fukushima',
        7214: 'Motomiya-shi, Fukushima',
        7301: 'Koori-machi, Fukushima',
        7303: 'Kunimi-machi, Fukushima',
        7308: 'Kawamata-machi, Fukushima',
        7322: 'Otama-mura, Fukushima',
        7342: 'Kagamiishi-machi, Fukushima',
        7344: 'Tenei-mura, Fukushima',
        7362: 'Shimogo-machi, Fukushima',
        7364: 'Hinoemata-mura, Fukushima',
        7367: 'Tadami-machi, Fukushima',
        7368: 'Minamiaizu-machi, Fukushima',
        7402: 'Kitashiobara-mura, Fukushima',
        7405: 'Nishiaizu-machi, Fukushima',
        7407: 'Bandai-machi, Fukushima',
        7408: 'Inawashiro-machi, Fukushima',
        7421: 'Aizubange-machi, Fukushima',
        7422: 'Yugawa-mura, Fukushima',
        7423: 'Yanaizu-machi, Fukushima',
        7444: 'Mishima-machi, Fukushima',
        7445: 'Kaneyama-machi, Fukushima',
        7446: 'Showa-mura, Fukushima',
        7447: 'Aizumisato-machi, Fukushima',
        7461: 'Nishigo-mura, Fukushima',
        7464: 'Izumizaki-mura, Fukushima',
        7465: 'Nakajima-mura, Fukushima',
        7466: 'Yabuki-machi, Fukushima',
        7481: 'Tanagura-machi, Fukushima',
        7482: 'Yamatsuri-machi, Fukushima',
        7483: 'Hanawa-machi, Fukushima',
        7484: 'Samegawa-mura, Fukushima',
        7501: 'Ishikawa-machi, Fukushima',
        7502: 'Tamakawa-mura, Fukushima',
        7503: 'Hirata-mura, Fukushima',
        7504: 'Asakawa-machi, Fukushima',
        7505: 'Furudono-machi, Fukushima',
        7521: 'Miharu-machi, Fukushima',
        7522: 'Ono-machi, Fukushima',
        7541: 'Hirono-machi, Fukushima',
        7542: 'Naraha-machi, Fukushima',
        7543: 'Tomioka-machi, Fukushima',
        7544: 'Kawauchi-mura, Fukushima',
        7545: 'Okuma-machi, Fukushima',
        7546: 'Futaba-machi, Fukushima',
        7547: 'Namie-machi, Fukushima',
        7548: 'Katsurao-mura, Fukushima',
        7561: 'Shinchi-machi, Fukushima',
        7564: 'Iitate-mura, Fukushima',
        8000: 'Ibaraki',
        8201: 'Mito-shi, Ibaraki',
        8202: 'Hitachi-shi, Ibaraki',
        8203: 'Tsuchiura-shi, Ibaraki',
        8204: 'Koga-shi, Ibaraki',
        8205: 'Ishioka-shi, Ibaraki',
        8207: 'Yuki-shi, Ibaraki',
        8208: 'Ryugasaki-shi, Ibaraki',
        8210: 'Shimotsuma-shi, Ibaraki',
        8211: 'Joso-shi, Ibaraki',
        8212: 'Hitachiota-shi, Ibaraki',
        8214: 'Takahagi-shi, Ibaraki',
        8215: 'Kitaibaraki-shi, Ibaraki',
        8216: 'Kasama-shi, Ibaraki',
        8217: 'Toride-shi, Ibaraki',
        8219: 'Ushiku-shi, Ibaraki',
        8220: 'Tsukuba-shi, Ibaraki',
        8221: 'Hitachinaka-shi, Ibaraki',
        8222: 'Kashima-shi, Ibaraki',
        8223: 'Itako-shi, Ibaraki',
        8224: 'Moriya-shi, Ibaraki',
        8225: 'Hitachiomiya-shi, Ibaraki',
        8226: 'Naka-shi, Ibaraki',
        8227: 'Chikusei-shi, Ibaraki',
        8228: 'Bando-shi, Ibaraki',
        8229: 'Inashiki-shi, Ibaraki',
        8230: 'Kasumigaura-shi, Ibaraki',
        8231: 'Sakuragawa-shi, Ibaraki',
        8232: 'Kamisu-shi, Ibaraki',
        8233: 'Namegata-shi, Ibaraki',
        8234: 'Hokota-shi, Ibaraki',
        8235: 'Tsukubamirai-shi, Ibaraki',
        8236: 'Omitama-shi, Ibaraki',
        8302: 'Ibaraki-machi, Ibaraki',
        8309: 'Oarai-machi, Ibaraki',
        8310: 'Shirosato-machi, Ibaraki',
        8341: 'Tokai-mura, Ibaraki',
        8364: 'Daigo-machi, Ibaraki',
        8442: 'Miho-mura, Ibaraki',
        8443: 'Ami-machi, Ibaraki',
        8447: 'Kawachi-machi, Ibaraki',
        8521: 'Yachiyo-machi, Ibaraki',
        8542: 'Goka-machi, Ibaraki',
        8546: 'Sakai-machi, Ibaraki',
        8564: 'Tone-machi, Ibaraki',
        9000: 'Tochigi',
        9201: 'Utsunomiya-shi, Tochigi',
        9202: 'Ashikaga-shi, Tochigi',
        9203: 'Tochigi-shi, Tochigi',
        9204: 'Sano-shi, Tochigi',
        9205: 'Kanuma-shi, Tochigi',
        9206: 'Nikko-shi, Tochigi',
        9208: 'Oyama-shi, Tochigi',
        9209: 'Moka-shi, Tochigi',
        9210: 'Otawara-shi, Tochigi',
        9211: 'Yaita-shi, Tochigi',
        9213: 'Nasushiobara-shi, Tochigi',
        9214: 'Sakura-shi, Tochigi',
        9215: 'Nasukarasuyama-shi, Tochigi',
        9216: 'Shimotsuke-shi, Tochigi',
        9301: 'Kaminokawa-machi, Tochigi',
        9342: 'Mashiko-machi, Tochigi',
        9343: 'Motegi-machi, Tochigi',
        9344: 'Ichikai-machi, Tochigi',
        9345: 'Haga-machi, Tochigi',
        9361: 'Mibu-machi, Tochigi',
        9364: 'Nogi-machi, Tochigi',
        9384: 'Shioya-machi, Tochigi',
        9386: 'Takanezawa-machi, Tochigi',
        9407: 'Nasu-machi, Tochigi',
        9411: 'Nakagawa-machi, Tochigi',
        10000: 'Gumma',
        10201: 'Maebashi-shi, Gumma',
        10202: 'Takasaki-shi, Gumma',
        10203: 'Kiryu-shi, Gumma',
        10204: 'Isesaki-shi, Gumma',
        10205: 'Ota-shi, Gumma',
        10206: 'Numata-shi, Gumma',
        10207: 'Tatebayashi-shi, Gumma',
        10208: 'Shibukawa-shi, Gumma',
        10209: 'Fujioka-shi, Gumma',
        10210: 'Tomioka-shi, Gumma',
        10211: 'Annaka-shi, Gumma',
        10212: 'Midori-shi, Gumma',
        10344: 'Shinto-mura, Gumma',
        10345: 'Yoshioka-machi, Gumma',
        10366: 'Ueno-mura, Gumma',
        10367: 'Kanna-machi, Gumma',
        10382: 'Shimonita-machi, Gumma',
        10383: 'Nammoku-mura, Gumma',
        10384: 'Kanra-machi, Gumma',
        10421: 'Nakanojiyo-machi, Gumma',
        10424: 'Naganohara-machi, Gumma',
        10425: 'Tsumagoi-mura, Gumma',
        10426: 'Kusatsu-machi, Gumma',
        10428: 'Takayama-mura, Gumma',
        10429: 'Higashiagatsuma-machi, Gumma',
        10443: 'Katashina-mura, Gumma',
        10444: 'Kawaba-mura, Gumma',
        10448: 'Showa-mura, Gumma',
        10449: 'Minakami-machi, Gumma',
        10464: 'Tamamura-machi, Gumma',
        10521: 'Itakura-machi, Gumma',
        10522: 'Meiwa-machi, Gumma',
        10523: 'Chiyoda-machi, Gumma',
        10524: 'Oizumi-machi, Gumma',
        10525: 'Ora-machi, Gumma',
        11000: 'Saitama',
        11100: 'Saitama-shi, Saitama',
        11101: 'Nishi-ku, Saitama-shi',
        11102: 'Kita-ku, Saitama-shi',
        11103: 'Omiya-ku, Saitama-shi',
        11104: 'Minuma-ku, Saitama-shi',
        11105: 'Chuo-ku, Saitama-shi',
        11106: 'Sakura-ku, Saitama-shi',
        11107: 'Urawa-ku, Saitama-shi',
        11108: 'Minami-ku, Saitama-shi',
        11109: 'Midori-ku, Saitama-shi',
        11110: 'Iwatsuki-ku, Saitama-shi',
        11201: 'Kawagoe-shi, Saitama',
        11202: 'Kumagaya-shi, Saitama',
        11203: 'Kawaguchi-shi, Saitama',
        11206: 'Giyoda-shi, Saitama',
        11207: 'Chichibu-shi, Saitama',
        11208: 'Tokorozawa-shi, Saitama',
        11209: 'Hanno-shi, Saitama',
        11210: 'Kazo-shi, Saitama',
        11211: 'Honjiyo-shi, Saitama',
        11212: 'Higashimatsuyama-shi, Saitama',
        11214: 'Kasukabe-shi, Saitama',
        11215: 'Sayama-shi, Saitama',
        11216: 'Haniyu-shi, Saitama',
        11217: 'Konosu-shi, Saitama',
        11218: 'Fukaya-shi, Saitama',
        11219: 'Ageo-shi, Saitama',
        11221: 'Soka-shi, Saitama',
        11222: 'Koshigaya-shi, Saitama',
        11223: 'Warabi-shi, Saitama',
        11224: 'Toda-shi, Saitama',
        11225: 'Iruma-shi, Saitama',
        11227: 'Asaka-shi, Saitama',
        11228: 'Shiki-shi, Saitama',
        11229: 'Wako-shi, Saitama',
        11230: 'Niiza-shi, Saitama',
        11231: 'Okegawa-shi, Saitama',
        11232: 'Kuki-shi, Saitama',
        11233: 'Kitamoto-shi, Saitama',
        11234: 'Yashio-shi, Saitama',
        11235: 'Fujimi-shi, Saitama',
        11237: 'Misato-shi, Saitama',
        11238: 'Hasuda-shi, Saitama',
        11239: 'Sakado-shi, Saitama',
        11240: 'Satte-shi, Saitama',
        11241: 'Tsurugashima-shi, Saitama',
        11242: 'Hidaka-shi, Saitama',
        11243: 'Yoshikawa-shi, Saitama',
        11245: 'Fujimino-shi, Saitama',
        11246: 'Shiraoka-shi, Saitama',
        11301: 'Ina-machi, Saitama',
        11324: 'Miyoshi-machi, Saitama',
        11326: 'Moroyama-machi, Saitama',
        11327: 'Ogose-machi, Saitama',
        11341: 'Namegawa-machi, Saitama',
        11342: 'Ranzan-machi, Saitama',
        11343: 'Ogawa-machi, Saitama',
        11346: 'Kawajima-machi, Saitama',
        11347: 'Yoshimi-machi, Saitama',
        11348: 'Hatoyama-machi, Saitama',
        11349: 'Tokigawa-machi, Saitama',
        11361: 'Yokoze-machi, Saitama',
        11362: 'Minano-machi, Saitama',
        11363: 'Nagatoro-machi, Saitama',
        11365: 'Ogano-machi, Saitama',
        11369: 'Higashichichibu-mura, Saitama',
        11381: 'Misato-machi, Saitama',
        11383: 'Kamikawa-machi, Saitama',
        11385: 'Kamisato-machi, Saitama',
        11408: 'Yorii-machi, Saitama',
        11442: 'Miyashiro-machi, Saitama',
        11464: 'Sugito-machi, Saitama',
        11465: 'Matsubushi-machi, Saitama',
        12000: 'Chiba',
        12100: 'Chiba-shi, Chiba',
        12101: 'Chuo-ku, Chiba-shi',
        12102: 'Hanamigawa-ku, Chiba-shi',
        12103: 'Inage-ku, Chiba-shi',
        12104: 'Wakaba-ku, Chiba-shi',
        12105: 'Midori-ku, Chiba-shi',
        12106: 'Mihama-ku, Chiba-shi',
        12202: 'Choshi-shi, Chiba',
        12203: 'Ichikawa-shi, Chiba',
        12204: 'Funabashi-shi, Chiba',
        12205: 'Tateyama-shi, Chiba',
        12206: 'Kisarazu-shi, Chiba',
        12207: 'Matsudo-shi, Chiba',
        12208: 'Noda-shi, Chiba',
        12210: 'Mobara-shi, Chiba',
        12211: 'Narita-shi, Chiba',
        12212: 'Sakura-shi, Chiba',
        12213: 'Togane-shi, Chiba',
        12215: 'Asahi-shi, Chiba',
        12216: 'Narashino-shi, Chiba',
        12217: 'Kashiwa-shi, Chiba',
        12218: 'Katsura-shi, Chiba',
        12219: 'Ichihara-shi, Chiba',
        12220: 'Nagareyama-shi, Chiba',
        12221: 'Yachiyo-shi, Chiba',
        12222: 'Abiko-shi, Chiba',
        12223: 'Kamogawa-shi, Chiba',
        12224: 'Kamagaya-shi, Chiba',
        12225: 'Kimitsu-shi, Chiba',
        12226: 'Futtsu-shi, Chiba',
        12227: 'Urayasu-shi, Chiba',
        12228: 'Yotsukaido-shi, Chiba',
        12229: 'Sodegaura-shi, Chiba',
        12230: 'Yachimata-shi, Chiba',
        12231: 'Inzai-shi, Chiba',
        12232: 'Shiroi-shi, Chiba',
        12233: 'Tomisato-shi, Chiba',
        12234: 'Minamiboso-shi, Chiba',
        12235: 'Sosa-shi, Chiba',
        12236: 'Katori-shi, Chiba',
        12237: 'Sammu-shi, Chiba',
        12238: 'Isumi-shi, Chiba',
        12239: 'Oamishirasato-shi, Chiba',
        12322: 'Shisui-machi, Chiba',
        12329: 'Sakae-machi, Chiba',
        12342: 'Kozaki-machi, Chiba',
        12347: 'Tako-machi, Chiba',
        12349: 'Tonosho-machi, Chiba',
        12403: 'Kujiyukuri-machi, Chiba',
        12409: 'Shibayama-machi, Chiba',
        12410: 'Yokoshibahikari-machi, Chiba',
        12421: 'Ichinomiya-machi, Chiba',
        12422: 'Mutsuzawa-machi, Chiba',
        12423: 'Chosei-mura, Chiba',
        12424: 'Shirako-machi, Chiba',
        12426: 'Nagara-machi, Chiba',
        12427: 'Chonan-machi, Chiba',
        12441: 'Otaki-machi, Chiba',
        12443: 'Onjiyuku-machi, Chiba',
        12463: 'Kiyonan-machi, Chiba',
        13000: 'Tokyo',
        13101: 'Chiyoda-ku, Tokyo',
        13102: 'Chuo-ku, Tokyo',
        13103: 'Minato-ku, Tokyo',
        13104: 'Shinjuku-ku, Tokyo',
        13105: 'Bunkyo-ku, Tokyo',
        13106: 'Taito-ku, Tokyo',
        13107: 'Sumida-ku, Tokyo',
        13108: 'Koto-ku, Tokyo',
        13109: 'Shinagawa-ku, Tokyo',
        13110: 'Meguro-ku, Tokyo',
        13111: 'Ota-ku, Tokyo',
        13112: 'Setagaya-ku, Tokyo',
        13113: 'Shibuya-ku, Tokyo',
        13114: 'Nakano-ku, Tokyo',
        13115: 'Suginami-ku, Tokyo',
        13116: 'Toshima-ku, Tokyo',
        13117: 'Kita-ku, Tokyo',
        13118: 'Arakawa-ku, Tokyo',
        13119: 'Itabashi-ku, Tokyo',
        13120: 'Nerima-ku, Tokyo',
        13121: 'Adachi-ku, Tokyo',
        13122: 'Katsushika-ku, Tokyo',
        13123: 'Edogawa-ku, Tokyo',
        13201: 'Hachioji-shi, Tokyo',
        13202: 'Tachikawa-shi, Tokyo',
        13203: 'Musashino-shi, Tokyo',
        13204: 'Mitaka-shi, Tokyo',
        13205: 'Ome-shi, Tokyo',
        13206: 'Fuchu-shi, Tokyo',
        13207: 'Akishima-shi, Tokyo',
        13208: 'Chofu-shi, Tokyo',
        13209: 'Machida-shi, Tokyo',
        13210: 'Koganei-shi, Tokyo',
        13211: 'Kodaira-shi, Tokyo',
        13212: 'Hino-shi, Tokyo',
        13213: 'Higashimurayama-shi, Tokyo',
        13214: 'Kokubunji-shi, Tokyo',
        13215: 'Kunitachi-shi, Tokyo',
        13218: 'Fussa-shi, Tokyo',
        13219: 'Komae-shi, Tokyo',
        13220: 'Higashiyamato-shi, Tokyo',
        13221: 'Kiyose-shi, Tokyo',
        13222: 'Higashikurume-shi, Tokyo',
        13223: 'Musashimurayama-shi, Tokyo',
        13224: 'Tama-shi, Tokyo',
        13225: 'Inagi-shi, Tokyo',
        13227: 'Hamura-shi, Tokyo',
        13228: 'Akiruno-shi, Tokyo',
        13229: 'Nishitokyo-shi, Tokyo',
        13303: 'Mizuho-machi, Tokyo',
        13305: 'Hinode-machi, Tokyo',
        13307: 'Hinohara-mura, Tokyo',
        13308: 'Okutama-machi, Tokyo',
        13361: 'Oshima-machi, Tokyo',
        13362: 'Toshima-mura, Tokyo',
        13363: 'Niijima-mura, Tokyo',
        13364: 'Kozushima-mura, Tokyo',
        13381: 'Miyake-mura, Tokyo',
        13382: 'Mikurajima-mura, Tokyo',
        13401: 'Hachijo-machi, Tokyo',
        13402: 'Aogashima-mura, Tokyo',
        13421: 'Ogasawara-mura, Tokyo',
        14000: 'Kanagawa',
        14100: 'Yokohama-shi, Kanagawa',
        14101: 'Tsurumi-ku, Yokohama-shi',
        14102: 'Kanagawa-ku, Yokohama-shi',
        14103: 'Nishi-ku, Yokohama-shi',
        14104: 'Naka-ku, Yokohama-shi',
        14105: 'Minami-ku, Yokohama-shi',
        14106: 'Hodogaya-ku, Yokohama-shi',
        14107: 'Isogo-ku, Yokohama-shi',
        14108: 'Kanazawa-ku, Yokohama-shi',
        14109: 'Kohoku-ku, Yokohama-shi',
        14110: 'Totsuka-ku, Yokohama-shi',
        14111: 'Konan-ku, Yokohama-shi',
        14112: 'Asahi-ku, Yokohama-shi',
        14113: 'Midori-ku, Yokohama-shi',
        14114: 'Seya-ku, Yokohama-shi',
        14115: 'Sakae-ku, Yokohama-shi',
        14116: 'Izumi-ku, Yokohama-shi',
        14117: 'Aoba-ku, Yokohama-shi',
        14118: 'Tsuzuki-ku, Yokohama-shi',
        14130: 'Kawasaki-shi, Kanagawa',
        14131: 'Kawasaki-ku, Kawasaki-shi',
        14132: 'Saiwai-ku, Kawasaki-shi',
        14133: 'Nakahara-ku, Kawasaki-shi',
        14134: 'Takatsu-ku, Kawasaki-shi',
        14135: 'Tama-ku, Kawasaki-shi',
        14136: 'Miyamae-ku, Kawasaki-shi',
        14137: 'Asao-ku, Kawasaki-shi',
        14150: 'Sagamihara-shi, Kanagawa',
        14151: 'Midori-ku, Sagamihara-shi',
        14152: 'Chuo-ku, Sagamihara-shi',
        14153: 'Minami-ku, Sagamihara-shi',
        14201: 'Yokosuka-shi, Kanagawa',
        14203: 'Hiratsuka-shi, Kanagawa',
        14204: 'Kamakura-shi, Kanagawa',
        14205: 'Fujisawa-shi, Kanagawa',
        14206: 'Odawara-shi, Kanagawa',
        14207: 'Chigasaki-shi, Kanagawa',
        14208: 'Zushi-shi, Kanagawa',
        14210: 'Miura-shi, Kanagawa',
        14211: 'Hadano-shi, Kanagawa',
        14212: 'Atsugi-shi, Kanagawa',
        14213: 'Yamato-shi, Kanagawa',
        14214: 'Isehara-shi, Kanagawa',
        14215: 'Ebina-shi, Kanagawa',
        14216: 'Zama-shi, Kanagawa',
        14217: 'Minamiashigara-shi, Kanagawa',
        14218: 'Ayase-shi, Kanagawa',
        14301: 'Hayama-machi, Kanagawa',
        14321: 'Samukawa-machi, Kanagawa',
        14341: 'Oiso-machi, Kanagawa',
        14342: 'Ninomiya-machi, Kanagawa',
        14361: 'Nakai-machi, Kanagawa',
        14362: 'Oi-machi, Kanagawa',
        14363: 'Matsuda-machi, Kanagawa',
        14364: 'Yamakita-machi, Kanagawa',
        14366: 'Kaisei-machi, Kanagawa',
        14382: 'Hakone-machi, Kanagawa',
        14383: 'Manatsuru-machi, Kanagawa',
        14384: 'Yugawara-machi, Kanagawa',
        14401: 'Aikawa-machi, Kanagawa',
        14402: 'Kiyokawa-mura, Kanagawa',
        15000: 'Niigata',
        15100: 'Niigata-shi, Niigata',
        15101: 'Kita-ku, Niigata-shi',
        15102: 'Higashi-ku, Niigata-shi',
        15103: 'Chuo-ku, Niigata-shi',
        15104: 'Konan-ku, Niigata-shi',
        15105: 'Akiha-ku, Niigata-shi',
        15106: 'Minami-ku, Niigata-shi',
        15107: 'Nishi-ku, Niigata-shi',
        15108: 'Nishikan-ku, Niigata-shi',
        15202: 'Nagaoka-shi, Niigata',
        15204: 'Sanjo-shi, Niigata',
        15205: 'Kashiwazaki-shi, Niigata',
        15206: 'Shibata-shi, Niigata',
        15208: 'Ojiya-shi, Niigata',
        15209: 'Kamo-shi, Niigata',
        15210: 'Tokamachi-shi, Niigata',
        15211: 'Mitsuke-shi, Niigata',
        15212: 'Murakami-shi, Niigata',
        15213: 'Tsubame-shi, Niigata',
        15216: 'Itoigawa-shi, Niigata',
        15217: 'Myoko-shi, Niigata',
        15218: 'Gosen-shi, Niigata',
        15222: 'Joetsu-shi, Niigata',
        15223: 'Agano-shi, Niigata',
        15224: 'Sado-shi, Niigata',
        15225: 'Uonuma-shi, Niigata',
        15226: 'Minamiuonuma-shi, Niigata',
        15227: 'Tainai-shi, Niigata',
        15307: 'Seiro-machi, Niigata',
        15342: 'Yahiko-mura, Niigata',
        15361: 'Tagami-machi, Niigata',
        15385: 'Aga-machi, Niigata',
        15405: 'Izumozaki-machi, Niigata',
        15461: 'Yuzawa-machi, Niigata',
        15482: 'Tsunan-machi, Niigata',
        15504: 'Kariwa-mura, Niigata',
        15581: 'Sekikawa-mura, Niigata',
        15586: 'Awashimaura-mura, Niigata',
        16000: 'Toyama',
        16201: 'Toyama-shi, Toyama',
        16202: 'Takaoka-shi, Toyama',
        16204: 'Uozu-shi, Toyama',
        16205: 'Himi-shi, Toyama',
        16206: 'Namerikawa-shi, Toyama',
        16207: 'Kurobe-shi, Toyama',
        16208: 'Tonami-shi, Toyama',
        16209: 'Oyabe-shi, Toyama',
        16210: 'Nanto-shi, Toyama',
        16211: 'Imizu-shi, Toyama',
        16321: 'Funahashi-mura, Toyama',
        16322: 'Kamiichi-machi, Toyama',
        16323: 'Tateyama-machi, Toyama',
        16342: 'Nyuzen-machi, Toyama',
        16343: 'Asahi-machi, Toyama',
        17000: 'Ishikawa',
        17201: 'Kanazawa-shi, Ishikawa',
        17202: 'Nanao-shi, Ishikawa',
        17203: 'Komatsu-shi, Ishikawa',
        17204: 'Wajima-shi, Ishikawa',
        17205: 'Suzu-shi, Ishikawa',
        17206: 'Kaga-shi, Ishikawa',
        17207: 'Hakui-shi, Ishikawa',
        17209: 'Kahoku-shi, Ishikawa',
        17210: 'Hakusan-shi, Ishikawa',
        17211: 'Nomi-shi, Ishikawa',
        17212: 'Nonoichi-shi, Ishikawa',
        17324: 'Kawakita-machi, Ishikawa',
        17361: 'Tsubata-machi, Ishikawa',
        17365: 'Uchinada-machi, Ishikawa',
        17384: 'Shika-machi, Ishikawa',
        17386: 'Hodatsushimizu-cho, Ishikawa',
        17407: 'Nakanoto-machi, Ishikawa',
        17461: 'Anamizu-machi, Ishikawa',
        17463: 'Noto-cho, Ishikawa',
        18000: 'Fukui',
        18201: 'Fukui-shi, Fukui',
        18202: 'Tsuruga-shi, Fukui',
        18204: 'Obama-shi, Fukui',
        18205: 'Ono-shi, Fukui',
        18206: 'Katsuyama-shi, Fukui',
        18207: 'Sabae-shi, Fukui',
        18208: 'Awara-shi, Fukui',
        18209: 'Echizen-shi, Fukui',
        18210: 'Sakai-shi, Fukui',
        18322: 'Eiheiji-cho, Fukui',
        18382: 'Ikeda-cho, Fukui',
        18404: 'Minamiechizen-cho, Fukui',
        18423: 'Echizen-cho, Fukui',
        18442: 'Mihama-cho, Fukui',
        18481: 'Takahama-cho, Fukui',
        18483: 'Oi-cho, Fukui',
        18501: 'Wakasa-cho, Fukui',
        19000: 'Yamanashi',
        19201: 'Kofu-shi, Yamanashi',
        19202: 'Fujiyoshida-shi, Yamanashi',
        19204: 'Tsuru-shi, Yamanashi',
        19205: 'Yamanashi-shi, Yamanashi',
        19206: 'Otsuki-shi, Yamanashi',
        19207: 'Nirasaki-shi, Yamanashi',
        19208: 'Minamiarupusu-shi, Yamanashi',
        19209: 'Hokuto-shi, Yamanashi',
        19210: 'Kai-shi, Yamanashi',
        19211: 'Fuefuki-shi, Yamanashi',
        19212: 'Uenohara-shi, Yamanashi',
        19213: 'Koshu-shi, Yamanashi',
        19214: 'Chuo-shi, Yamanashi',
        19346: 'Ichikawamisato-cho, Yamanashi',
        19364: 'Hayakawa-cho, Yamanashi',
        19365: 'Minobu-cho, Yamanashi',
        19366: 'Nambu-cho, Yamanashi',
        19368: 'Fujikawa-cho, Yamanashi',
        19384: 'Showa-cho, Yamanashi',
        19422: 'Doshi-mura, Yamanashi',
        19423: 'Nishikatsura-cho, Yamanashi',
        19424: 'Oshino-mura, Yamanashi',
        19425: 'Yamanakako-mura, Yamanashi',
        19429: 'Narusawa-mura, Yamanashi',
        19430: 'Fujikawaguchiko-machi, Yamanashi',
        19442: 'Kosuge-mura, Yamanashi',
        19443: 'Tabayama-mura, Yamanashi',
        20000: 'Nagano',
        20201: 'Nagano-shi, Nagano',
        20202: 'Matsumoto-shi, Nagano',
        20203: 'Ueda-shi, Nagano',
        20204: 'Okaya-shi, Nagano',
        20205: 'Iida-shi, Nagano',
        20206: 'Suwa-shi, Nagano',
        20207: 'Suzaka-shi, Nagano',
        20208: 'Komoro-shi, Nagano',
        20209: 'Ina-shi, Nagano',
        20210: 'Komagane-shi, Nagano',
        20211: 'Nakano-shi, Nagano',
        20212: 'Omachi-shi, Nagano',
        20213: 'Iiyama-shi, Nagano',
        20214: 'Chino-shi, Nagano',
        20215: 'Shiojiri-shi, Nagano',
        20217: 'Saku-shi, Nagano',
        20218: 'Chikuma-shi, Nagano',
        20219: 'Tomi-shi, Nagano',
        20220: 'Azumino-shi, Nagano',
        20303: 'Koumi-machi, Nagano',
        20304: 'Kawakami-mura, Nagano',
        20305: 'Minamimaki-mura, Nagano',
        20306: 'Minamiaiki-mura, Nagano',
        20307: 'Kitaaiki-mura, Nagano',
        20309: 'Sakuho-machi, Nagano',
        20321: 'Karuizawa-machi, Nagano',
        20323: 'Miyota-machi, Nagano',
        20324: 'Tateshina-machi, Nagano',
        20349: 'Aoki-mura, Nagano',
        20350: 'Nagawa-machi, Nagano',
        20361: 'Shimosuwa-machi, Nagano',
        20362: 'Fujimi-machi, Nagano',
        20363: 'Hara-mura, Nagano',
        20382: 'Tatsuno-machi, Nagano',
        20383: 'Minowa-machi, Nagano',
        20384: 'Iijima-machi, Nagano',
        20385: 'Minamiminowa-mura, Nagano',
        20386: 'Nakagawa-mura, Nagano',
        20388: 'Miyada-mura, Nagano',
        20402: 'Matsukawa-machi, Nagano',
        20403: 'Takamori-machi, Nagano',
        20404: 'Anan-cho, Nagano',
        20407: 'Achi-mura, Nagano',
        20409: 'Hiraya-mura, Nagano',
        20410: 'Neba-mura, Nagano',
        20411: 'Shimojo-mura, Nagano',
        20412: 'Urugi-mura, Nagano',
        20413: 'Tenryu-mura, Nagano',
        20414: 'Yasuoka-mura, Nagano',
        20415: 'Takagi-mura, Nagano',
        20416: 'Toyooka-mura, Nagano',
        20417: 'Oshika-mura, Nagano',
        20422: 'Agematsu-machi, Nagano',
        20423: 'Nagiso-machi, Nagano',
        20425: 'Kiso-mura, Nagano',
        20429: 'Otaki-mura, Nagano',
        20430: 'Okuwa-mura, Nagano',
        20432: 'Kiso-machi, Nagano',
        20446: 'Omi-mura, Nagano',
        20448: 'Ikusaka-mura, Nagano',
        20450: 'Yamagata-mura, Nagano',
        20451: 'Asahi-mura, Nagano',
        20452: 'Chikuhoku-mura, Nagano',
        20481: 'Ikeda-machi, Nagano',
        20482: 'Matsukawa-mura, Nagano',
        20485: 'Hakuba-mura, Nagano',
        20486: 'Otari-mura, Nagano',
        20521: 'Sakaki-machi, Nagano',
        20541: 'Obuse-machi, Nagano',
        20543: 'Takayama-mura, Nagano',
        20561: 'Yamanouchi-machi, Nagano',
        20562: 'Kijimadaira-mura, Nagano',
        20563: 'Nozawaonsen-mura, Nagano',
        20583: 'Shinano-machi, Nagano',
        20588: 'Ogawa-mura, Nagano',
        20590: 'Iizuna-machi, Nagano',
        20602: 'Sakae-mura, Nagano',
        21000: 'Gifu',
        21201: 'Gifu-shi, Gifu',
        21202: 'Ogaki-shi, Gifu',
        21203: 'Takayama-shi, Gifu',
        21204: 'Tajimi-shi, Gifu',
        21205: 'Seki-shi, Gifu',
        21206: 'Nakatsugawa-shi, Gifu',
        21207: 'Mino-shi, Gifu',
        21208: 'Mizunami-shi, Gifu',
        21209: 'Hashima-shi, Gifu',
        21210: 'Ena-shi, Gifu',
        21211: 'Minokamo-shi, Gifu',
        21212: 'Toki-shi, Gifu',
        21213: 'Kakamigahara-shi, Gifu',
        21214: 'Kani-shi, Gifu',
        21215: 'Yamagata-shi, Gifu',
        21216: 'Mizuho-shi, Gifu',
        21217: 'Hida-shi, Gifu',
        21218: 'Motosu-shi, Gifu',
        21219: 'Gujo-shi, Gifu',
        21220: 'Gero-shi, Gifu',
        21221: 'Kaizu-shi, Gifu',
        21302: 'Ginan-cho, Gifu',
        21303: 'Kasamatsu-cho, Gifu',
        21341: 'Yoro-cho, Gifu',
        21361: 'Tarui-cho, Gifu',
        21362: 'Sekigahara-cho, Gifu',
        21381: 'Godo-cho, Gifu',
        21382: 'Wanouchi-cho, Gifu',
        21383: 'Ampachi-cho, Gifu',
        21401: 'Ibigawa-cho, Gifu',
        21403: 'Ono-cho, Gifu',
        21404: 'Ikeda-cho, Gifu',
        21421: 'Kitagata-cho, Gifu',
        21501: 'Sakahogi-cho, Gifu',
        21502: 'Tomika-cho, Gifu',
        21503: 'Kawabe-cho, Gifu',
        21504: 'Hichiso-cho, Gifu',
        21505: 'Yaotsu-cho, Gifu',
        21506: 'Shirakawa-cho, Gifu',
        21507: 'Higashishirakawa-mura, Gifu',
        21521: 'Mitake-cho, Gifu',
        21604: 'Shirakawa-mura, Gifu',
        22000: 'Shizuoka',
        22100: 'Shizuoka-shi, Shizuoka',
        22101: 'Aoi-ku, Shizuoka-shi',
        22102: 'Suruga-ku, Shizuoka-shi',
        22103: 'Shimizu-ku, Shizuoka-shi',
        22130: 'Hamamatsu-shi, Shizuoka',
        22131: 'Naka-ku, Hamamatsu-shi',
        22132: 'Higashi-ku, Hamamatsu-shi',
        22133: 'Nishi-ku, Hamamatsu-shi',
        22134: 'Minami-ku, Hamamatsu-shi',
        22135: 'Kita-ku, Hamamatsu-shi',
        22136: 'Hamakita-ku, Hamamatsu-shi',
        22137: 'Tenryu-ku, Hamamatsu-shi',
        22138: 'Naka-ku, Hamamatsu-shi',
        22139: 'Hamakita-ku, Hamamatsu-shi',
        22140: 'Tenryu-ku, Hamamatsu-shi',
        22203: 'Numazu-shi, Shizuoka',
        22205: 'Atami-shi, Shizuoka',
        22206: 'Mishima-shi, Shizuoka',
        22207: 'Fujinomiya-shi, Shizuoka',
        22208: 'Ito-shi, Shizuoka',
        22209: 'Shimada-shi, Shizuoka',
        22210: 'Fuji-shi, Shizuoka',
        22211: 'Iwata-shi, Shizuoka',
        22212: 'Yaizu-shi, Shizuoka',
        22213: 'Kakegawa-shi, Shizuoka',
        22214: 'Fujieda-shi, Shizuoka',
        22215: 'Gotemba-shi, Shizuoka',
        22216: 'Fukuroi-shi, Shizuoka',
        22219: 'Shimoda-shi, Shizuoka',
        22220: 'Susono-shi, Shizuoka',
        22221: 'Kosai-shi, Shizuoka',
        22222: 'Izu-shi, Shizuoka',
        22223: 'Omaezaki-shi, Shizuoka',
        22224: 'Kikugawa-shi, Shizuoka',
        22225: 'Izunokuni-shi, Shizuoka',
        22226: 'Makinohara-shi, Shizuoka',
        22301: 'Higashiizu-cho, Shizuoka',
        22302: 'Kawazu-cho, Shizuoka',
        22304: 'Minamiizu-cho, Shizuoka',
        22305: 'Matsuzaki-cho, Shizuoka',
        22306: 'Nishiizu-cho, Shizuoka',
        22325: 'Kannami-cho, Shizuoka',
        22341: 'Shimizu-cho, Shizuoka',
        22342: 'Nagaizumi-cho, Shizuoka',
        22344: 'Oyama-cho, Shizuoka',
        22424: 'Yoshida-cho, Shizuoka',
        22429: 'Kawanehon-cho, Shizuoka',
        22461: 'Mori-machi, Shizuoka',
        23000: 'Aichi',
        23100: 'Nagoya-shi, Aichi',
        23101: 'Chikusa-ku, Nagoya-shi',
        23102: 'Higashi-ku, Nagoya-shi',
        23103: 'Kita-ku, Nagoya-shi',
        23104: 'Nishi-ku, Nagoya-shi',
        23105: 'Nakamura-ku, Nagoya-shi',
        23106: 'Naka-ku, Nagoya-shi',
        23107: 'Showa-ku, Nagoya-shi',
        23108: 'Mizuho-ku, Nagoya-shi',
        23109: 'Atsuta-ku, Nagoya-shi',
        23110: 'Nakagawa-ku, Nagoya-shi',
        23111: 'Minato-ku, Nagoya-shi',
        23112: 'Minami-ku, Nagoya-shi',
        23113: 'Moriyama-ku, Nagoya-shi',
        23114: 'Midori-ku, Nagoya-shi',
        23115: 'Meito-ku, Nagoya-shi',
        23116: 'Tempaku-ku, Nagoya-shi',
        23201: 'Toyohashi-shi, Aichi',
        23202: 'Okazaki-shi, Aichi',
        23203: 'Ichinomiya-shi, Aichi',
        23204: 'Seto-shi, Aichi',
        23205: 'Handa-shi, Aichi',
        23206: 'Kasugai-shi, Aichi',
        23207: 'Toyokawa-shi, Aichi',
        23208: 'Tsushima-shi, Aichi',
        23209: 'Hekinan-shi, Aichi',
        23210: 'Kariya-shi, Aichi',
        23211: 'Toyota-shi, Aichi',
        23212: 'Anjo-shi, Aichi',
        23213: 'Nishio-shi, Aichi',
        23214: 'Gamagori-shi, Aichi',
        23215: 'Inuyama-shi, Aichi',
        23216: 'Tokoname-shi, Aichi',
        23217: 'Konan-shi, Aichi',
        23219: 'Komaki-shi, Aichi',
        23220: 'Inazawa-shi, Aichi',
        23221: 'Shinshiro-shi, Aichi',
        23222: 'Tokai-shi, Aichi',
        23223: 'Obu-shi, Aichi',
        23224: 'Chita-shi, Aichi',
        23225: 'Chiryu-shi, Aichi',
        23226: 'Owariasahi-shi, Aichi',
        23227: 'Takahama-shi, Aichi',
        23228: 'Iwakura-shi, Aichi',
        23229: 'Toyoake-shi, Aichi',
        23230: 'Nisshin-shi, Aichi',
        23231: 'Tahara-shi, Aichi',
        23232: 'Aisai-shi, Aichi',
        23233: 'Kiyosu-shi, Aichi',
        23234: 'Kitanagoya-shi, Aichi',
        23235: 'Yatomi-shi, Aichi',
        23236: 'Miyoshi-shi, Aichi',
        23237: 'Ama-shi, Aichi',
        23238: 'Nagakute-shi, Aichi',
        23302: 'Togo-cho, Aichi',
        23342: 'Toyoyama-cho, Aichi',
        23361: 'Oguchi-cho, Aichi',
        23362: 'Fuso-cho, Aichi',
        23424: 'Oharu-cho, Aichi',
        23425: 'Kanie-cho, Aichi',
        23427: 'Tobishima-mura, Aichi',
        23441: 'Agui-cho, Aichi',
        23442: 'Higashiura-cho, Aichi',
        23445: 'Minamichita-cho, Aichi',
        23446: 'Mihama-cho, Aichi',
        23447: 'Taketoyo-cho, Aichi',
        23501: 'Kota-cho, Aichi',
        23561: 'Shitara-cho, Aichi',
        23562: 'Toei-cho, Aichi',
        23563: 'Toyone-mura, Aichi',
        24000: 'Mie',
        24201: 'Tsu-shi, Mie',
        24202: 'Yokkaichi-shi, Mie',
        24203: 'Ise-shi, Mie',
        24204: 'Matsusaka-shi, Mie',
        24205: 'Kuwana-shi, Mie',
        24207: 'Suzuka-shi, Mie',
        24208: 'Nabari-shi, Mie',
        24209: 'Owase-shi, Mie',
        24210: 'Kameyama-shi, Mie',
        24211: 'Toba-shi, Mie',
        24212: 'Kumano-shi, Mie',
        24214: 'Inabe-shi, Mie',
        24215: 'Shima-shi, Mie',
        24216: 'Iga-shi, Mie',
        24303: 'Kisosaki-cho, Mie',
        24324: 'Toin-cho, Mie',
        24341: 'Komono-cho, Mie',
        24343: 'Asahi-cho, Mie',
        24344: 'Kawagoe-cho, Mie',
        24441: 'Taki-cho, Mie',
        24442: 'Meiwa-cho, Mie',
        24443: 'Odai-cho, Mie',
        24461: 'Tamaki-cho, Mie',
        24470: 'Watarai-cho, Mie',
        24471: 'Taiki-cho, Mie',
        24472: 'Minamiise-cho, Mie',
        24543: 'Kihoku-cho, Mie',
        24561: 'Mihama-cho, Mie',
        24562: 'Kiho-cho, Mie',
        25000: 'Shiga',
        25201: 'Otsu-shi, Shiga',
        25202: 'Hikone-shi, Shiga',
        25203: 'Nagahama-shi, Shiga',
        25204: 'Omihachiman-shi, Shiga',
        25206: 'Kusatsu-shi, Shiga',
        25207: 'Moriyama-shi, Shiga',
        25208: 'Ritto-shi, Shiga',
        25209: 'Koka-shi, Shiga',
        25210: 'Yasu-shi, Shiga',
        25211: 'Konan-shi, Shiga',
        25212: 'Takashima-shi, Shiga',
        25213: 'Higashiomi-shi, Shiga',
        25214: 'Maibara-shi, Shiga',
        25383: 'Hino-cho, Shiga',
        25384: 'Riyuo-cho, Shiga',
        25425: 'Aisho-cho, Shiga',
        25441: 'Toyosato-cho, Shiga',
        25442: 'Kora-cho, Shiga',
        25443: 'Taga-cho, Shiga',
        26000: 'Kyoto',
        26100: 'Kyoto-shi, Kyoto',
        26101: 'Kita-ku, Kyoto-shi',
        26102: 'Kamigyo-ku, Kyoto-shi',
        26103: 'Sakyo-ku, Kyoto-shi',
        26104: 'Nakagyo-ku, Kyoto-shi',
        26105: 'Higashiyama-ku, Kyoto-shi',
        26106: 'Shimogyo-ku, Kyoto-shi',
        26107: 'Minami-ku, Kyoto-shi',
        26108: 'Ukyo-ku, Kyoto-shi',
        26109: 'Fushimi-ku, Kyoto-shi',
        26110: 'Yamashina-ku, Kyoto-shi',
        26111: 'Nishikyo-ku, Kyoto-shi',
        26201: 'Fukuchiyama-shi, Kyoto',
        26202: 'Maizuru-shi, Kyoto',
        26203: 'Ayabe-shi, Kyoto',
        26204: 'Uji-shi, Kyoto',
        26205: 'Miyazu-shi, Kyoto',
        26206: 'Kameoka-shi, Kyoto',
        26207: 'Joyo-shi, Kyoto',
        26208: 'Muko-shi, Kyoto',
        26209: 'Nagaokakyo-shi, Kyoto',
        26210: 'Yawata-shi, Kyoto',
        26211: 'Kyotanabe-shi, Kyoto',
        26212: 'Kyotango-shi, Kyoto',
        26213: 'Nantan-shi, Kyoto',
        26214: 'Kizugawa-shi, Kyoto',
        26303: 'Oyamazaki-cho, Kyoto',
        26322: 'Kumiyama-cho, Kyoto',
        26343: 'Ide-cho, Kyoto',
        26344: 'Ujitawara-cho, Kyoto',
        26364: 'Kasagi-cho, Kyoto',
        26365: 'Wazuka-cho, Kyoto',
        26366: 'Seika-cho, Kyoto',
        26367: 'Minamiyamashiro-mura, Kyoto',
        26407: 'Kyotamba-cho, Kyoto',
        26463: 'Ine-cho, Kyoto',
        26465: 'Yosano-cho, Kyoto',
        27000: 'Osaka',
        27100: 'Osaka-shi, Osaka',
        27101: 'Kita-ku, Osaka-shi',
        27102: 'Miyakojima-ku, Osaka-shi',
        27103: 'Fukushima-ku, Osaka-shi',
        27104: 'Konohana-ku, Osaka-shi',
        27105: 'Higashi-ku, Osaka-shi',
        27106: 'Nishi-ku, Osaka-shi',
        27107: 'Minato-ku, Osaka-shi',
        27108: 'Taisho-ku, Osaka-shi',
        27109: 'Tennoji-ku, Osaka-shi',
        27110: 'Minami-ku, Osaka-shi',
        27111: 'Naniwa-ku, Osaka-shi',
        27112: 'Oyodo-ku, Osaka-shi',
        27113: 'Nishiyodogawa-ku, Osaka-shi',
        27114: 'Higashiyodogawa-ku, Osaka-shi',
        27115: 'Higashinari-ku, Osaka-shi',
        27116: 'Ikuno-ku, Osaka-shi',
        27117: 'Asahi-ku, Osaka-shi',
        27118: 'Joto-ku, Osaka-shi',
        27119: 'Abeno-ku, Osaka-shi',
        27120: 'Sumiyoshi-ku, Osaka-shi',
        27121: 'Higashisumiyoshi-ku, Osaka-shi',
        27122: 'Nishinari-ku, Osaka-shi',
        27123: 'Yodogawa-ku, Osaka-shi',
        27124: 'Tsurumi-ku, Osaka-shi',
        27125: 'Suminoe-ku, Osaka-shi',
        27126: 'Hirano-ku, Osaka-shi',
        27127: 'Kita-ku, Osaka-shi',
        27128: 'Chuo-ku, Osaka-shi',
        27140: 'Sakai-shi, Osaka',
        27141: 'Sakai-ku, Sakai-shi',
        27142: 'Naka-ku, Sakai-shi',
        27143: 'Higashi-ku, Sakai-shi',
        27144: 'Nishi-ku, Sakai-shi',
        27145: 'Minami-ku, Sakai-shi',
        27146: 'Kita-ku, Sakai-shi',
        27147: 'Mihara-ku, Sakai-shi',
        27202: 'Kishiwada-shi, Osaka',
        27203: 'Toyonaka-shi, Osaka',
        27204: 'Ikeda-shi, Osaka',
        27205: 'Suita-shi, Osaka',
        27206: 'Izumiotsu-shi, Osaka',
        27207: 'Takatsuki-shi, Osaka',
        27208: 'Kaizuka-shi, Osaka',
        27209: 'Moriguchi-shi, Osaka',
        27210: 'Hirakata-shi, Osaka',
        27211: 'Ibaraki-shi, Osaka',
        27212: 'Yao-shi, Osaka',
        27213: 'Izumisano-shi, Osaka',
        27214: 'Tondabayashi-shi, Osaka',
        27215: 'Neyagawa-shi, Osaka',
        27216: 'Kawachinagano-shi, Osaka',
        27217: 'Matsubara-shi, Osaka',
        27218: 'Daito-shi, Osaka',
        27219: 'Izumi-shi, Osaka',
        27220: 'Mino-shi, Osaka',
        27221: 'Kashiwara-shi, Osaka',
        27222: 'Habikino-shi, Osaka',
        27223: 'Kadoma-shi, Osaka',
        27224: 'Settsu-shi, Osaka',
        27225: 'Takaishi-shi, Osaka',
        27226: 'Fujiidera-shi, Osaka',
        27227: 'Higashiosaka-shi, Osaka',
        27228: 'Sennan-shi, Osaka',
        27229: 'Shijiyonawate-shi, Osaka',
        27230: 'Katano-shi, Osaka',
        27231: 'Osakasayama-shi, Osaka',
        27232: 'Hannan-shi, Osaka',
        27301: 'Shimamoto-cho, Osaka',
        27321: 'Toyono-cho, Osaka',
        27322: 'Nose-cho, Osaka',
        27341: 'Tadaoka-cho, Osaka',
        27361: 'Kumatori-cho, Osaka',
        27362: 'Tajiri-cho, Osaka',
        27366: 'Misaki-cho, Osaka',
        27381: 'Taishi-cho, Osaka',
        27382: 'Kanan-cho, Osaka',
        27383: 'Chihayaakasaka-mura, Osaka',
        28000: 'Hyogo',
        28100: 'Kobe-shi, Hyogo',
        28101: 'Higashinada-ku, Kobe-shi',
        28102: 'Nada-ku, Kobe-shi',
        28103: 'Fukiai-ku, Kobe-shi',
        28104: 'Ikuta-ku, Kobe-shi',
        28105: 'Hyogo-ku, Kobe-shi',
        28106: 'Nagata-ku, Kobe-shi',
        28107: 'Suma-ku, Kobe-shi',
        28108: 'Tarumi-ku, Kobe-shi',
        28109: 'Kita-ku, Kobe-shi',
        28110: 'Chuo-ku, Kobe-shi',
        28111: 'Nishi-ku, Kobe-shi',
        28201: 'Himeji-shi, Hyogo',
        28202: 'Amagasaki-shi, Hyogo',
        28203: 'Akashi-shi, Hyogo',
        28204: 'Nishinomiya-shi, Hyogo',
        28205: 'Sumoto-shi, Hyogo',
        28206: 'Ashiya-shi, Hyogo',
        28207: 'Itami-shi, Hyogo',
        28208: 'Aioi-shi, Hyogo',
        28209: 'Toyoka-shi, Hyogo',
        28210: 'Kakogawa-shi, Hyogo',
        28212: 'Ako-shi, Hyogo',
        28213: 'Nishiwaki-shi, Hyogo',
        28214: 'Takarazuka-shi, Hyogo',
        28215: 'Miki-shi, Hyogo',
        28216: 'Takasago-shi, Hyogo',
        28217: 'Kawanishi-shi, Hyogo',
        28218: 'Ono-shi, Hyogo',
        28219: 'Sanda-shi, Hyogo',
        28220: 'Kasai-shi, Hyogo',
        28221: 'Tambasasayama-shi, Hyogo',
        28222: 'Yabu-shi, Hyogo',
        28223: 'Tamba-shi, Hyogo',
        28224: 'Minamiawaji-shi, Hyogo',
        28225: 'Asago-shi, Hyogo',
        28226: 'Awaji-shi, Hyogo',
        28227: 'Shiso-shi, Hyogo',
        28228: 'Kato-shi, Hyogo',
        28229: 'Tatsuno-shi, Hyogo',
        28301: 'Inagawa-cho, Hyogo',
        28365: 'Taka-cho, Hyogo',
        28381: 'Inami-cho, Hyogo',
        28382: 'Harima-cho, Hyogo',
        28442: 'Ichikawa-cho, Hyogo',
        28443: 'Fukusaki-cho, Hyogo',
        28446: 'Kamikawa-cho, Hyogo',
        28464: 'Taishi-cho, Hyogo',
        28481: 'Kamigori-cho, Hyogo',
        28501: 'Sayo-cho, Hyogo',
        28585: 'Kami-cho, Hyogo',
        28586: 'Shinonsen-cho, Hyogo',
        29000: 'Nara',
        29201: 'Nara-shi, Nara',
        29202: 'Yamatotakada-shi, Nara',
        29203: 'Yamatokoriyama-shi, Nara',
        29204: 'Tenri-shi, Nara',
        29205: 'Kashihara-shi, Nara',
        29206: 'Sakurai-shi, Nara',
        29207: 'Gojo-shi, Nara',
        29208: 'Gose-shi, Nara',
        29209: 'Ikoma-shi, Nara',
        29210: 'Kashiba-shi, Nara',
        29211: 'Katsuragi-shi, Nara',
        29212: 'Uda-shi, Nara',
        29322: 'Yamazoe-mura, Nara',
        29342: 'Heguri-cho, Nara',
        29343: 'Sango-cho, Nara',
        29344: 'Ikaruga-cho, Nara',
        29345: 'Ando-cho, Nara',
        29361: 'Kawanishi-cho, Nara',
        29362: 'Miyake-cho, Nara',
        29363: 'Tawaramoto-cho, Nara',
        29385: 'Soni-mura, Nara',
        29386: 'Mitsue-mura, Nara',
        29401: 'Takatori-cho, Nara',
        29402: 'Asuka-mura, Nara',
        29424: 'Kammaki-cho, Nara',
        29425: 'Oji-cho, Nara',
        29426: 'Koriyo-cho, Nara',
        29427: 'Kawai-cho, Nara',
        29441: 'Yoshino-cho, Nara',
        29442: 'Oyodo-cho, Nara',
        29443: 'Shimoichi-cho, Nara',
        29444: 'Kurotaki-mura, Nara',
        29446: 'Tenkawa-mura, Nara',
        29447: 'Nosegawa-mura, Nara',
        29449: 'Totsukawa-mura, Nara',
        29450: 'Shimokitayama-mura, Nara',
        29451: 'Kamikitayama-mura, Nara',
        29452: 'Kawakami-mura, Nara',
        29453: 'Higashiyoshino-mura, Nara',
        30000: 'Wakayama',
        30201: 'Wakayama-shi, Wakayama',
        30202: 'Kainan-shi, Wakayama',
        30203: 'Hashimoto-shi, Wakayama',
        30204: 'Arida-shi, Wakayama',
        30205: 'Gobo-shi, Wakayama',
        30206: 'Tanabe-shi, Wakayama',
        30207: 'Shingu-shi, Wakayama',
        30208: 'Kinokawa-shi, Wakayama',
        30209: 'Iwade-shi, Wakayama',
        30304: 'Kimino-cho, Wakayama',
        30341: 'Katsuragi-cho, Wakayama',
        30343: 'Kudoyama-cho, Wakayama',
        30344: 'Koya-cho, Wakayama',
        30361: 'Yuasa-cho, Wakayama',
        30362: 'Hirogawa-cho, Wakayama',
        30366: 'Aridagawa-cho, Wakayama',
        30381: 'Mihama-cho, Wakayama',
        30382: 'Hidaka-cho, Wakayama',
        30383: 'Yura-cho, Wakayama',
        30390: 'Inami-cho, Wakayama',
        30391: 'Minabe-cho, Wakayama',
        30392: 'Hidakagawa-cho, Wakayama',
        30401: 'Shirahama-cho, Wakayama',
        30404: 'Kamitonda-cho, Wakayama',
        30406: 'Susami-cho, Wakayama',
        30421: 'Nachikatsura-cho, Wakayama',
        30422: 'Taiji-cho, Wakayama',
        30424: 'Kozagawa-cho, Wakayama',
        30427: 'Kitayama-mura, Wakayama',
        30428: 'Kushimoto-cho, Wakayama',
        31000: 'Tottori',
        31201: 'Tottori-shi, Tottori',
        31202: 'Yonago-shi, Tottori',
        31203: 'Kurayoshi-shi, Tottori',
        31204: 'Sakaiminato-shi, Tottori',
        31302: 'Iwami-cho, Tottori',
        31325: 'Wakasa-cho, Tottori',
        31328: 'Chizu-cho, Tottori',
        31329: 'Yazu-cho, Tottori',
        31364: 'Misasa-cho, Tottori',
        31370: 'Yurihama-cho, Tottori',
        31371: 'Kotoura-cho, Tottori',
        31372: 'Hokuei-cho, Tottori',
        31384: 'Hiezu-son, Tottori',
        31386: 'Daisen-cho, Tottori',
        31389: 'Nambu-cho, Tottori',
        31390: 'Hoki-cho, Tottori',
        31401: 'Nichinan-cho, Tottori',
        31402: 'Hino-cho, Tottori',
        31403: 'Kofu-cho, Tottori',
        32000: 'Shimane',
        32201: 'Matsue-shi, Shimane',
        32202: 'Hamada-shi, Shimane',
        32203: 'Izumo-shi, Shimane',
        32204: 'Masuda-shi, Shimane',
        32205: 'Oda-shi, Shimane',
        32206: 'Yasugi-shi, Shimane',
        32207: 'Gotsu-shi, Shimane',
        32209: 'Unnan-shi, Shimane',
        32343: 'Okuizumo-cho, Shimane',
        32386: 'Iinan-cho, Shimane',
        32441: 'Kawamoto-machi, Shimane',
        32448: 'Misato-cho, Shimane',
        32449: 'Onan-cho, Shimane',
        32501: 'Tsuwano-cho, Shimane',
        32505: 'Yoshika-cho, Shimane',
        32525: 'Ama-cho, Shimane',
        32526: 'Nishinoshima-cho, Shimane',
        32527: 'Chibu-mura, Shimane',
        32528: 'Okinoshima-cho, Shimane',
        33000: 'Okayama',
        33100: 'Okayama-shi, Okayama',
        33101: 'Kita-ku, Okayama-shi',
        33102: 'Naka-ku, Okayama-shi',
        33103: 'Higashi-ku, Okayama-shi',
        33104: 'Minami-ku, Okayama-shi',
        33202: 'Kurashiki-shi, Okayama',
        33203: 'Tsuyama-shi, Okayama',
        33204: 'Tamano-shi, Okayama',
        33205: 'Kasaoka-shi, Okayama',
        33207: 'Ibara-shi, Okayama',
        33208: 'Sojiya-shi, Okayama',
        33209: 'Takahashi-shi, Okayama',
        33210: 'Niimi-shi, Okayama',
        33211: 'Bizen-shi, Okayama',
        33212: 'Setouchi-shi, Okayama',
        33213: 'Akaiwa-shi, Okayama',
        33214: 'Maniwa-shi, Okayama',
        33215: 'Mimasaka-shi, Okayama',
        33216: 'Asakuchi-shi, Okayama',
        33346: 'Wake-cho, Okayama',
        33423: 'Hayashima-cho, Okayama',
        33445: 'Satosho-cho, Okayama',
        33461: 'Yakage-cho, Okayama',
        33586: 'Shinjiyo-son, Okayama',
        33606: 'Kagamino-cho, Okayama',
        33622: 'Shoo-cho, Okayama',
        33623: 'Nagi-cho, Okayama',
        33643: 'Nishiawakura-son, Okayama',
        33663: 'Kumenan-cho, Okayama',
        33666: 'Misaki-cho, Okayama',
        33681: 'Kibichuo-cho, Okayama',
        34000: 'Hiroshima',
        34100: 'Hiroshima-shi, Hiroshima',
        34101: 'Naka-ku, Hiroshima-shi',
        34102: 'Higashi-ku, Hiroshima-shi',
        34103: 'Minami-ku, Hiroshima-shi',
        34104: 'Nishi-ku, Hiroshima-shi',
        34105: 'Asaminami-ku, Hiroshima-shi',
        34106: 'Asakita-ku, Hiroshima-shi',
        34107: 'Aki-ku, Hiroshima-shi',
        34108: 'Saeki-ku, Hiroshima-shi',
        34202: 'Kure-shi, Hiroshima',
        34203: 'Takehara-shi, Hiroshima',
        34204: 'Mihara-shi, Hiroshima',
        34205: 'Onomichi-shi, Hiroshima',
        34207: 'Fukuyama-shi, Hiroshima',
        34208: 'Fuchu-shi, Hiroshima',
        34209: 'Miyoshi-shi, Hiroshima',
        34210: 'Shobara-shi, Hiroshima',
        34211: 'Otake-shi, Hiroshima',
        34212: 'Higashihiroshima-shi, Hiroshima',
        34213: 'Hatsukaichi-shi, Hiroshima',
        34214: 'Akitakata-shi, Hiroshima',
        34215: 'Etajima-shi, Hiroshima',
        34302: 'Fuchu-cho, Hiroshima',
        34304: 'Kaita-cho, Hiroshima',
        34307: 'Kumano-cho, Hiroshima',
        34309: 'Saka-cho, Hiroshima',
        34368: 'Akiota-cho, Hiroshima',
        34369: 'Kitahiroshima-cho, Hiroshima',
        34431: 'Osakikamijima-cho, Hiroshima',
        34462: 'Sera-cho, Hiroshima',
        34545: 'Jinsekikogen-cho, Hiroshima',
        35000: 'Yamaguchi',
        35201: 'Shimonoseki-shi, Yamaguchi',
        35202: 'Ube-shi, Yamaguchi',
        35203: 'Yamaguchi-shi, Yamaguchi',
        35204: 'Hagi-shi, Yamaguchi',
        35206: 'Hofu-shi, Yamaguchi',
        35207: 'Kudamatsu-shi, Yamaguchi',
        35208: 'Iwakuni-shi, Yamaguchi',
        35210: 'Hikari-shi, Yamaguchi',
        35211: 'Nagato-shi, Yamaguchi',
        35212: 'Yanai-shi, Yamaguchi',
        35213: 'Mine-shi, Yamaguchi',
        35215: 'Shunan-shi, Yamaguchi',
        35216: 'Sanyoonoda-shi, Yamaguchi',
        35305: 'Suooshima-cho, Yamaguchi',
        35321: 'Waki-cho, Yamaguchi',
        35341: 'Kaminoseki-cho, Yamaguchi',
        35343: 'Tabuse-cho, Yamaguchi',
        35344: 'Hirao-cho, Yamaguchi',
        35502: 'Abu-cho, Yamaguchi',
        36000: 'Tokushima',
        36201: 'Tokushima-shi, Tokushima',
        36202: 'Naruto-shi, Tokushima',
        36203: 'Komatsushima-shi, Tokushima',
        36204: 'Anan-shi, Tokushima',
        36205: 'Yoshinogawa-shi, Tokushima',
        36206: 'Awa-shi, Tokushima',
        36207: 'Mima-shi, Tokushima',
        36208: 'Miyoshi-shi, Tokushima',
        36301: 'Katsura-cho, Tokushima',
        36302: 'Kamikatsu-cho, Tokushima',
        36321: 'Sanagochi-son, Tokushima',
        36341: 'Ishii-cho, Tokushima',
        36342: 'Kamiyama-cho, Tokushima',
        36368: 'Naka-cho, Tokushima',
        36383: 'Mugi-cho, Tokushima',
        36387: 'Minami-cho, Tokushima',
        36388: 'Kaiyo-cho, Tokushima',
        36401: 'Matsushige-cho, Tokushima',
        36402: 'Kitajima-cho, Tokushima',
        36403: 'Aizumi-cho, Tokushima',
        36404: 'Itano-cho, Tokushima',
        36405: 'Kamiita-cho, Tokushima',
        36468: 'Tsurugi-cho, Tokushima',
        36489: 'Higashimiyoshi-cho, Tokushima',
        37000: 'Kagawa',
        37201: 'Takamatsu-shi, Kagawa',
        37202: 'Marugame-shi, Kagawa',
        37203: 'Sakaide-shi, Kagawa',
        37204: 'Zentsuji-shi, Kagawa',
        37205: 'Kanonji-shi, Kagawa',
        37206: 'Sanuki-shi, Kagawa',
        37207: 'Higashikagawa-shi, Kagawa',
        37208: 'Mitoyo-shi, Kagawa',
        37322: 'Tonosho-cho, Kagawa',
        37324: 'Shodoshima-cho, Kagawa',
        37341: 'Miki-cho, Kagawa',
        37364: 'Naoshima-cho, Kagawa',
        37386: 'Utazu-cho, Kagawa',
        37387: 'Ayagawa-cho, Kagawa',
        37403: 'Kotohira-cho, Kagawa',
        37404: 'Tadotsu-cho, Kagawa',
        37406: 'Manno-cho, Kagawa',
        38000: 'Ehime',
        38201: 'Matsuyama-shi, Ehime',
        38202: 'Imabari-shi, Ehime',
        38203: 'Uwajima-shi, Ehime',
        38204: 'Yawatahama-shi, Ehime',
        38205: 'Niihama-shi, Ehime',
        38206: 'Saijo-shi, Ehime',
        38207: 'Ozu-shi, Ehime',
        38210: 'Iyo-shi, Ehime',
        38213: 'Shikokuchuo-shi, Ehime',
        38214: 'Seiyo-shi, Ehime',
        38215: 'Toon-shi, Ehime',
        38356: 'Kamijima-cho, Ehime',
        38386: 'Kumakogen-cho, Ehime',
        38401: 'Masaki-cho, Ehime',
        38402: 'Tobe-cho, Ehime',
        38422: 'Uchiko-cho, Ehime',
        38442: 'Ikata-cho, Ehime',
        38484: 'Matsuno-cho, Ehime',
        38488: 'Kihoku-cho, Ehime',
        38506: 'Ainan-cho, Ehime',
        39000: 'Kochi',
        39201: 'Kochi-shi, Kochi',
        39202: 'Muroto-shi, Kochi',
        39203: 'Aki-shi, Kochi',
        39204: 'Nankoku-shi, Kochi',
        39205: 'Tosa-shi, Kochi',
        39206: 'Susaki-shi, Kochi',
        39208: 'Sukumo-shi, Kochi',
        39209: 'Tosashimizu-shi, Kochi',
        39210: 'Shimanto-shi, Kochi',
        39211: 'Konan-shi, Kochi',
        39212: 'Kami-shi, Kochi',
        39301: 'Toyo-cho, Kochi',
        39302: 'Nahari-cho, Kochi',
        39303: 'Tano-cho, Kochi',
        39304: 'Yasuda-cho, Kochi',
        39305: 'Kitagawa-mura, Kochi',
        39306: 'Umaji-mura, Kochi',
        39307: 'Geisei-mura, Kochi',
        39341: 'Motoyama-cho, Kochi',
        39344: 'Otoyo-cho, Kochi',
        39363: 'Tosa-cho, Kochi',
        39364: 'Okawa-mura, Kochi',
        39386: 'Ino-cho, Kochi',
        39387: 'Niyodogawa-cho, Kochi',
        39401: 'Nakatosa-cho, Kochi',
        39402: 'Sakawa-cho, Kochi',
        39403: 'Ochi-cho, Kochi',
        39405: 'Yusuhara-cho, Kochi',
        39410: 'Hidaka-mura, Kochi',
        39411: 'Tsuno-cho, Kochi',
        39412: 'Shimanto-cho, Kochi',
        39424: 'Otsuki-cho, Kochi',
        39427: 'Mihara-mura, Kochi',
        39428: 'Kuroshio-cho, Kochi',
        40000: 'Fukuoka',
        40100: 'Kitakyushu-shi, Fukuoka',
        40101: 'Moji-ku, Kitakyushu-shi',
        40102: 'Kokura-ku, Kitakyushu-shi',
        40103: 'Wakamatsu-ku, Kitakyushu-shi',
        40104: 'Yahata-ku, Kitakyushu-shi',
        40105: 'Tobata-ku, Kitakyushu-shi',
        40106: 'Kokurakita-ku, Kitakyushu-shi',
        40107: 'Kokuraminami-ku, Kitakyushu-shi',
        40108: 'Yahatahigashi-ku, Kitakyushu-shi',
        40109: 'Yahatanishi-ku, Kitakyushu-shi',
        40130: 'Fukuoka-shi, Fukuoka',
        40131: 'Higashi-ku, Fukuoka-shi',
        40132: 'Hakata-ku, Fukuoka-shi',
        40133: 'Chuo-ku, Fukuoka-shi',
        40134: 'Minami-ku, Fukuoka-shi',
        40135: 'Nishi-ku, Fukuoka-shi',
        40136: 'Jonan-ku, Fukuoka-shi',
        40137: 'Sawara-ku, Fukuoka-shi',
        40202: 'Omuta-shi, Fukuoka',
        40203: 'Kurume-shi, Fukuoka',
        40204: 'Nogata-shi, Fukuoka',
        40205: 'Iizuka-shi, Fukuoka',
        40206: 'Tagawa-shi, Fukuoka',
        40207: 'Yanagawa-shi, Fukuoka',
        40210: 'Yame-shi, Fukuoka',
        40211: 'Chikugo-shi, Fukuoka',
        40212: 'Okawa-shi, Fukuoka',
        40213: 'Yukuhashi-shi, Fukuoka',
        40214: 'Buzen-shi, Fukuoka',
        40215: 'Nakama-shi, Fukuoka',
        40216: 'Ogori-shi, Fukuoka',
        40217: 'Chikushino-shi, Fukuoka',
        40218: 'Kasuga-shi, Fukuoka',
        40219: 'Onojo-shi, Fukuoka',
        40220: 'Munakata-shi, Fukuoka',
        40221: 'Dazaifu-shi, Fukuoka',
        40223: 'Koga-shi, Fukuoka',
        40224: 'Fukutsu-shi, Fukuoka',
        40225: 'Ukiha-shi, Fukuoka',
        40226: 'Miyawaka-shi, Fukuoka',
        40227: 'Kama-shi, Fukuoka',
        40228: 'Asakura-shi, Fukuoka',
        40229: 'Miyama-shi, Fukuoka',
        40230: 'Itoshima-shi, Fukuoka',
        40231: 'Nakagawa-shi, Fukuoka',
        40341: 'Umi-machi, Fukuoka',
        40342: 'Sasaguri-machi, Fukuoka',
        40343: 'Shime-machi, Fukuoka',
        40344: 'Sue-machi, Fukuoka',
        40345: 'Shingu-machi, Fukuoka',
        40348: 'Hisayama-machi, Fukuoka',
        40349: 'Kasuya-machi, Fukuoka',
        40381: 'Ashiya-machi, Fukuoka',
        40382: 'Mizumaki-machi, Fukuoka',
        40383: 'Okagaki-machi, Fukuoka',
        40384: 'Onga-cho, Fukuoka',
        40401: 'Kotake-machi, Fukuoka',
        40402: 'Kurate-machi, Fukuoka',
        40421: 'Keisen-machi, Fukuoka',
        40447: 'Chikuzen-machi, Fukuoka',
        40448: 'Toho-mura, Fukuoka',
        40503: 'Tachiarai-machi, Fukuoka',
        40522: 'Oki-machi, Fukuoka',
        40544: 'Hirokawa-machi, Fukuoka',
        40601: 'Kawara-machi, Fukuoka',
        40602: 'Soeda-machi, Fukuoka',
        40604: 'Itoda-machi, Fukuoka',
        40605: 'Kawasaki-machi, Fukuoka',
        40608: 'Oto-machi, Fukuoka',
        40609: 'Aka-mura, Fukuoka',
        40610: 'Fukuchi-machi, Fukuoka',
        40621: 'Kanda-machi, Fukuoka',
        40625: 'Miyako-machi, Fukuoka',
        40642: 'Yoshitomi-machi, Fukuoka',
        40646: 'Koge-machi, Fukuoka',
        40647: 'Chikujo-machi, Fukuoka',
        41000: 'Saga',
        41201: 'Saga-shi, Saga',
        41202: 'Karatsu-shi, Saga',
        41203: 'Tosu-shi, Saga',
        41204: 'Taku-shi, Saga',
        41205: 'Imari-shi, Saga',
        41206: 'Takeo-shi, Saga',
        41207: 'Kashima-shi, Saga',
        41208: 'Ogi-shi, Saga',
        41209: 'Ureshino-shi, Saga',
        41210: 'Kanzaki-shi, Saga',
        41327: 'Yoshinogari-cho, Saga',
        41341: 'Kiyama-cho, Saga',
        41345: 'Kamimine-cho, Saga',
        41346: 'Miyaki-cho, Saga',
        41387: 'Genkai-cho, Saga',
        41401: 'Arita-cho, Saga',
        41423: 'Omachi-cho, Saga',
        41424: 'Kohoku-machi, Saga',
        41425: 'Shiroishi-cho, Saga',
        41441: 'Tara-cho, Saga',
        42000: 'Nagasaki',
        42201: 'Nagasaki-shi, Nagasaki',
        42202: 'Sasebo-shi, Nagasaki',
        42203: 'Shimabara-shi, Nagasaki',
        42204: 'Isahaya-shi, Nagasaki',
        42205: 'Omura-shi, Nagasaki',
        42207: 'Hirado-shi, Nagasaki',
        42208: 'Matsura-shi, Nagasaki',
        42209: 'Tsushima-shi, Nagasaki',
        42210: 'Iki-shi, Nagasaki',
        42211: 'Goto-shi, Nagasaki',
        42212: 'Saikai-shi, Nagasaki',
        42213: 'Unzen-shi, Nagasaki',
        42214: 'Minamishimabara-shi, Nagasaki',
        42307: 'Nagayo-cho, Nagasaki',
        42308: 'Togitsu-cho, Nagasaki',
        42321: 'Higashisonogi-cho, Nagasaki',
        42322: 'Kawatana-cho, Nagasaki',
        42323: 'Hasami-cho, Nagasaki',
        42383: 'Ojika-cho, Nagasaki',
        42391: 'Saza-cho, Nagasaki',
        42411: 'Shinkamigoto-cho, Nagasaki',
        43000: 'Kumamoto',
        43100: 'Kumamoto-shi, Kumamoto',
        43101: 'Chuo-ku, Kumamoto-shi',
        43102: 'Higashi-ku, Kumamoto-shi',
        43103: 'Nishi-ku, Kumamoto-shi',
        43104: 'Minami-ku, Kumamoto-shi',
        43105: 'Kita-ku, Kumamoto-shi',
        43202: 'Yatsushiro-shi, Kumamoto',
        43203: 'Hitoyoshi-shi, Kumamoto',
        43204: 'Arao-shi, Kumamoto',
        43205: 'Minamata-shi, Kumamoto',
        43206: 'Tamana-shi, Kumamoto',
        43208: 'Yamaga-shi, Kumamoto',
        43210: 'Kikuchi-shi, Kumamoto',
        43211: 'Uto-shi, Kumamoto',
        43212: 'Kamiamakusa-shi, Kumamoto',
        43213: 'Uki-shi, Kumamoto',
        43214: 'Aso-shi, Kumamoto',
        43215: 'Amakusa-shi, Kumamoto',
        43216: 'Koshi-shi, Kumamoto',
        43348: 'Misato-machi, Kumamoto',
        43364: 'Gyokuto-machi, Kumamoto',
        43367: 'Nankan-machi, Kumamoto',
        43368: 'Nagasu-machi, Kumamoto',
        43369: 'Nagomi-machi, Kumamoto',
        43403: 'Ozu-machi, Kumamoto',
        43404: 'Kikuyo-machi, Kumamoto',
        43423: 'Minamioguni-machi, Kumamoto',
        43424: 'Oguni-machi, Kumamoto',
        43425: 'Ubuyama-mura, Kumamoto',
        43428: 'Takamori-machi, Kumamoto',
        43432: 'Nishihara-mura, Kumamoto',
        43433: 'Minamiaso-mura, Kumamoto',
        43441: 'Mifune-machi, Kumamoto',
        43442: 'Kashima-machi, Kumamoto',
        43443: 'Mashiki-machi, Kumamoto',
        43444: 'Kosa-machi, Kumamoto',
        43447: 'Yamato-cho, Kumamoto',
        43468: 'Hikawa-cho, Kumamoto',
        43482: 'Ashikita-machi, Kumamoto',
        43484: 'Tsunagi-machi, Kumamoto',
        43501: 'Nishiki-machi, Kumamoto',
        43505: 'Taragi-machi, Kumamoto',
        43506: 'Yunomae-machi, Kumamoto',
        43507: 'Mizukami-mura, Kumamoto',
        43510: 'Sagara-mura, Kumamoto',
        43511: 'Itsuki-mura, Kumamoto',
        43512: 'Yamae-mura, Kumamoto',
        43513: 'Kuma-mura, Kumamoto',
        43514: 'Asagiri-cho, Kumamoto',
        43531: 'Reihoku-machi, Kumamoto',
        44000: 'Oita',
        44201: 'Oita-shi, Oita',
        44202: 'Beppu-shi, Oita',
        44203: 'Nakatsu-shi, Oita',
        44204: 'Hita-shi, Oita',
        44205: 'Saiki-shi, Oita',
        44206: 'Usuki-shi, Oita',
        44207: 'Tsukumi-shi, Oita',
        44208: 'Taketa-shi, Oita',
        44209: 'Bungotakada-shi, Oita',
        44210: 'Kitsuki-shi, Oita',
        44211: 'Usa-shi, Oita',
        44212: 'Bungoono-shi, Oita',
        44213: 'Yufu-shi, Oita',
        44214: 'Kunisaki-shi, Oita',
        44322: 'Himeshima-mura, Oita',
        44341: 'Hiji-machi, Oita',
        44461: 'Kokonoe-machi, Oita',
        44462: 'Kusu-machi, Oita',
        45000: 'Miyazaki',
        45201: 'Miyazaki-shi, Miyazaki',
        45202: 'Miyakonojo-shi, Miyazaki',
        45203: 'Nobeoka-shi, Miyazaki',
        45204: 'Nichinan-shi, Miyazaki',
        45205: 'Kobayashi-shi, Miyazaki',
        45206: 'Hyuga-shi, Miyazaki',
        45207: 'Kushima-shi, Miyazaki',
        45208: 'Saito-shi, Miyazaki',
        45209: 'Ebino-shi, Miyazaki',
        45341: 'Mimata-cho, Miyazaki',
        45361: 'Takaharu-cho, Miyazaki',
        45382: 'Kunitomi-cho, Miyazaki',
        45383: 'Aya-cho, Miyazaki',
        45401: 'Takanabe-cho, Miyazaki',
        45402: 'Shintomi-cho, Miyazaki',
        45403: 'Nishimera-son, Miyazaki',
        45404: 'Kijo-cho, Miyazaki',
        45405: 'Kawaminami-cho, Miyazaki',
        45406: 'Tsuno-cho, Miyazaki',
        45421: 'Kadogawa-cho, Miyazaki',
        45429: 'Morotsuka-son, Miyazaki',
        45430: 'Shiiba-son, Miyazaki',
        45431: 'Misato-cho, Miyazaki',
        45441: 'Takachiho-cho, Miyazaki',
        45442: 'Hinokage-cho, Miyazaki',
        45443: 'Gokase-cho, Miyazaki',
        46000: 'Kagoshima',
        46201: 'Kagoshima-shi, Kagoshima',
        46203: 'Kanoya-shi, Kagoshima',
        46204: 'Makurazaki-shi, Kagoshima',
        46206: 'Akune-shi, Kagoshima',
        46208: 'Izumi-shi, Kagoshima',
        46210: 'Ibusuki-shi, Kagoshima',
        46213: 'Nishinoomote-shi, Kagoshima',
        46214: 'Tarumizu-shi, Kagoshima',
        46215: 'Satsumasendai-shi, Kagoshima',
        46216: 'Hioki-shi, Kagoshima',
        46217: 'Soo-shi, Kagoshima',
        46218: 'Kirishima-shi, Kagoshima',
        46219: 'Ichikikushikino-shi, Kagoshima',
        46220: 'Minamisatsuma-shi, Kagoshima',
        46221: 'Shibushi-shi, Kagoshima',
        46222: 'Amami-shi, Kagoshima',
        46223: 'Minamikyushu-shi, Kagoshima',
        46224: 'Isa-shi, Kagoshima',
        46225: 'Aira-shi, Kagoshima',
        46303: 'Mishima-mura, Kagoshima',
        46304: 'Toshima-mura, Kagoshima',
        46392: 'Satsuma-cho, Kagoshima',
        46404: 'Nagashima-cho, Kagoshima',
        46452: 'Yusui-cho, Kagoshima',
        46468: 'Osaki-cho, Kagoshima',
        46482: 'Higashikushira-cho, Kagoshima',
        46490: 'Kinko-cho, Kagoshima',
        46491: 'Minamiosumi-cho, Kagoshima',
        46492: 'Kimotsuki-cho, Kagoshima',
        46501: 'Nakatane-cho, Kagoshima',
        46502: 'Minamitane-cho, Kagoshima',
        46505: 'Yakushima-cho, Kagoshima',
        46523: 'Yamato-son, Kagoshima',
        46524: 'Uken-son, Kagoshima',
        46525: 'Setouchi-cho, Kagoshima',
        46527: 'Tatsugo-cho, Kagoshima',
        46529: 'Kikai-cho, Kagoshima',
        46530: 'Tokunoshima-cho, Kagoshima',
        46531: 'Amagi-cho, Kagoshima',
        46532: 'Isen-cho, Kagoshima',
        46533: 'Wadomari-cho, Kagoshima',
        46534: 'China-cho, Kagoshima',
        46535: 'Yoron-cho, Kagoshima',
        47000: 'Okinawa',
        47201: 'Naha-shi, Okinawa',
        47205: 'Ginowan-shi, Okinawa',
        47207: 'Ishigaki-shi, Okinawa',
        47208: 'Urasoe-shi, Okinawa',
        47209: 'Nago-shi, Okinawa',
        47210: 'Itoman-shi, Okinawa',
        47211: 'Okinawa-shi, Okinawa',
        47212: 'Tomigusuku-shi, Okinawa',
        47213: 'Uruma-shi, Okinawa',
        47214: 'Miyakojima-shi, Okinawa',
        47215: 'Nanjo-shi, Okinawa',
        47301: 'Kunigami-son, Okinawa',
        47302: 'Ogimi-son, Okinawa',
        47303: 'Higashi-son, Okinawa',
        47306: 'Nakijin-son, Okinawa',
        47308: 'Motobu-cho, Okinawa',
        47311: 'Onna-son, Okinawa',
        47313: 'Ginoza-son, Okinawa',
        47314: 'Kin-cho, Okinawa',
        47315: 'Ie-son, Okinawa',
        47324: 'Yomitan-son, Okinawa',
        47325: 'Kadena-cho, Okinawa',
        47326: 'Chiyatan-cho, Okinawa',
        47327: 'Kitanakagusuku-son, Okinawa',
        47328: 'Nakagusuku-son, Okinawa',
        47329: 'Nishihara-cho, Okinawa',
        47348: 'Yonabaru-cho, Okinawa',
        47350: 'Haebaru-cho, Okinawa',
        47353: 'Tokashiki-son, Okinawa',
        47354: 'Zamami-son, Okinawa',
        47355: 'Aguni-son, Okinawa',
        47356: 'Tonaki-son, Okinawa',
        47357: 'Minamidaito-son, Okinawa',
        47358: 'Kitadaito-son, Okinawa',
        47359: 'Iheya-son, Okinawa',
        47360: 'Izena-son, Okinawa',
        47361: 'Kumejima-cho, Okinawa',
        47362: 'Yaese-cho, Okinawa',
        47375: 'Tarama-son, Okinawa',
        47381: 'Taketomi-cho, Okinawa',
        47382: 'Yonaguni-cho, Okinawa',
    },
    undefined='Undefined city, town and village name in Japan (Code: %d)'
)


qzss_dcx_ex1_target_area_code_ja = QzssDcrDefinition(
    {
        1000: '北海道',
        1100: '北海道札幌市',
        1101: '札幌市中央区',
        1102: '札幌市北区',
        1103: '札幌市東区',
        1104: '札幌市白石区',
        1105: '札幌市豊平区',
        1106: '札幌市南区',
        1107: '札幌市西区',
        1108: '札幌市厚別区',
        1109: '札幌市手稲区',
        1110: '札幌市清田区',
        1202: '北海道函館市',
        1203: '北海道小樽市',
        1204: '北海道旭川市',
        1205: '北海道室蘭市',
        1206: '北海道釧路市',
        1207: '北海道帯広市',
        1208: '北海道北見市',
        1209: '北海道夕張市',
        1210: '北海道岩見沢市',
        1211: '北海道網走市',
        1212: '北海道留萌市',
        1213: '北海道苫小牧市',
        1214: '北海道稚内市',
        1215: '北海道美唄市',
        1216: '北海道芦別市',
        1217: '北海道江別市',
        1218: '北海道赤平市',
        1219: '北海道紋別市',
        1220: '北海道士別市',
        1221: '北海道名寄市',
        1222: '北海道三笠市',
        1223: '北海道根室市',
        1224: '北海道千歳市',
        1225: '北海道滝川市',
        1226: '北海道砂川市',
        1227: '北海道歌志内市',
        1228: '北海道深川市',
        1229: '北海道富良野市',
        1230: '北海道登別市',
        1231: '北海道恵庭市',
        1233: '北海道伊達市',
        1234: '北海道北広島市',
        1235: '北海道石狩市',
        1236: '北海道北斗市',
        1303: '北海道当別町',
        1304: '北海道新篠津村',
        1331: '北海道松前町',
        1332: '北海道福島町',
        1333: '北海道知内町',
        1334: '北海道木古内町',
        1337: '北海道七飯町',
        1343: '北海道鹿部町',
        1345: '北海道森町',
        1346: '北海道八雲町',
        1347: '北海道長万部町',
        1361: '北海道江差町',
        1362: '北海道上ノ国町',
        1363: '北海道厚沢部町',
        1364: '北海道乙部町',
        1367: '北海道奥尻町',
        1370: '北海道今金町',
        1371: '北海道せたな町',
        1391: '北海道島牧村',
        1392: '北海道寿都町',
        1393: '北海道黒松内町',
        1394: '北海道蘭越町',
        1395: '北海道ニセコ町',
        1396: '北海道真狩村',
        1397: '北海道留寿都村',
        1398: '北海道喜茂別町',
        1399: '北海道京極町',
        1400: '北海道倶知安町',
        1401: '北海道共和町',
        1402: '北海道岩内町',
        1403: '北海道泊村',
        1404: '北海道神恵内村',
        1405: '北海道積丹町',
        1406: '北海道古平町',
        1407: '北海道仁木町',
        1408: '北海道余市町',
        1409: '北海道赤井川村',
        1423: '北海道南幌町',
        1424: '北海道奈井江町',
        1425: '北海道上砂川町',
        1427: '北海道由仁町',
        1428: '北海道長沼町',
        1429: '北海道栗山町',
        1430: '北海道月形町',
        1431: '北海道浦臼町',
        1432: '北海道新十津川町',
        1433: '北海道妹背牛町',
        1434: '北海道秩父別町',
        1436: '北海道雨竜町',
        1437: '北海道北竜町',
        1438: '北海道沼田町',
        1452: '北海道鷹栖町',
        1453: '北海道東神楽町',
        1454: '北海道当麻町',
        1455: '北海道比布町',
        1456: '北海道愛別町',
        1457: '北海道上川町',
        1458: '北海道東川町',
        1459: '北海道美瑛町',
        1460: '北海道上富良野町',
        1461: '北海道中富良野町',
        1462: '北海道南富良野町',
        1463: '北海道占冠村',
        1464: '北海道和寒町',
        1465: '北海道剣淵町',
        1468: '北海道下川町',
        1469: '北海道美深町',
        1470: '北海道音威子府村',
        1471: '北海道中川町',
        1472: '北海道幌加内町',
        1481: '北海道増毛町',
        1482: '北海道小平町',
        1483: '北海道苫前町',
        1484: '北海道羽幌町',
        1485: '北海道初山別村',
        1486: '北海道遠別町',
        1487: '北海道天塩町',
        1511: '北海道猿払村',
        1512: '北海道浜頓別町',
        1513: '北海道中頓別町',
        1514: '北海道枝幸町',
        1516: '北海道豊富町',
        1517: '北海道礼文町',
        1518: '北海道利尻町',
        1519: '北海道利尻富士町',
        1520: '北海道幌延町',
        1543: '北海道美幌町',
        1544: '北海道津別町',
        1545: '北海道斜里町',
        1546: '北海道清里町',
        1547: '北海道小清水町',
        1549: '北海道訓子府町',
        1550: '北海道置戸町',
        1552: '北海道佐呂間町',
        1555: '北海道遠軽町',
        1559: '北海道湧別町',
        1560: '北海道滝上町',
        1561: '北海道興部町',
        1562: '北海道西興部村',
        1563: '北海道雄武町',
        1564: '北海道大空町',
        1571: '北海道豊浦町',
        1575: '北海道壮瞥町',
        1578: '北海道白老町',
        1581: '北海道厚真町',
        1584: '北海道洞爺湖町',
        1585: '北海道安平町',
        1586: '北海道むかわ町',
        1601: '北海道日高町',
        1602: '北海道平取町',
        1604: '北海道新冠町',
        1607: '北海道浦河町',
        1608: '北海道様似町',
        1609: '北海道えりも町',
        1610: '北海道新ひだか町',
        1631: '北海道音更町',
        1632: '北海道士幌町',
        1633: '北海道上士幌町',
        1634: '北海道鹿追町',
        1635: '北海道新得町',
        1636: '北海道清水町',
        1637: '北海道芽室町',
        1638: '北海道中札内村',
        1639: '北海道更別村',
        1641: '北海道大樹町',
        1642: '北海道広尾町',
        1643: '北海道幕別町',
        1644: '北海道池田町',
        1645: '北海道豊頃町',
        1646: '北海道本別町',
        1647: '北海道足寄町',
        1648: '北海道陸別町',
        1649: '北海道浦幌町',
        1661: '北海道釧路町',
        1662: '北海道厚岸町',
        1663: '北海道浜中町',
        1664: '北海道標茶町',
        1665: '北海道弟子屈町',
        1667: '北海道鶴居村',
        1668: '北海道白糠町',
        1691: '北海道別海町',
        1692: '北海道中標津町',
        1693: '北海道標津町',
        1694: '北海道羅臼町',
        1695: '北海道色丹村',
        1696: '北海道泊村',
        1697: '北海道留夜別村',
        1698: '北海道留別村',
        1699: '北海道紗那村',
        1700: '北海道蘂取村',
        2000: '青森県',
        2201: '青森県青森市',
        2202: '青森県弘前市',
        2203: '青森県八戸市',
        2204: '青森県黒石市',
        2205: '青森県五所川原市',
        2206: '青森県十和田市',
        2207: '青森県三沢市',
        2208: '青森県むつ市',
        2209: '青森県つがる市',
        2210: '青森県平川市',
        2301: '青森県平内町',
        2303: '青森県今別町',
        2304: '青森県蓬田村',
        2307: '青森県外ヶ浜町',
        2321: '青森県鰺ヶ沢町',
        2323: '青森県深浦町',
        2343: '青森県西目屋村',
        2361: '青森県藤崎町',
        2362: '青森県大鰐町',
        2367: '青森県田舎館村',
        2381: '青森県板柳町',
        2384: '青森県鶴田町',
        2387: '青森県中泊町',
        2401: '青森県野辺地町',
        2402: '青森県七戸町',
        2405: '青森県六戸町',
        2406: '青森県横浜町',
        2408: '青森県東北町',
        2411: '青森県六ヶ所村',
        2412: '青森県おいらせ町',
        2423: '青森県大間町',
        2424: '青森県東通村',
        2425: '青森県風間浦村',
        2426: '青森県佐井村',
        2441: '青森県三戸町',
        2442: '青森県五戸町',
        2443: '青森県田子町',
        2445: '青森県南部町',
        2446: '青森県階上町',
        2450: '青森県新郷村',
        3000: '岩手県',
        3201: '岩手県盛岡市',
        3202: '岩手県宮古市',
        3203: '岩手県大船渡市',
        3205: '岩手県花巻市',
        3206: '岩手県北上市',
        3207: '岩手県久慈市',
        3208: '岩手県遠野市',
        3209: '岩手県一関市',
        3210: '岩手県陸前高田市',
        3211: '岩手県釜石市',
        3213: '岩手県二戸市',
        3214: '岩手県八幡平市',
        3215: '岩手県奥州市',
        3216: '岩手県滝沢市',
        3301: '岩手県雫石町',
        3302: '岩手県葛巻町',
        3303: '岩手県岩手町',
        3321: '岩手県紫波町',
        3322: '岩手県矢巾町',
        3366: '岩手県西和賀町',
        3381: '岩手県金ケ崎町',
        3402: '岩手県平泉町',
        3441: '岩手県住田町',
        3461: '岩手県大槌町',
        3482: '岩手県山田町',
        3483: '岩手県岩泉町',
        3484: '岩手県田野畑村',
        3485: '岩手県普代村',
        3501: '岩手県軽米町',
        3503: '岩手県野田村',
        3506: '岩手県九戸村',
        3507: '岩手県洋野町',
        3524: '岩手県一戸町',
        4000: '宮城県',
        4100: '宮城県仙台市',
        4101: '仙台市青葉区',
        4102: '仙台市宮城野区',
        4103: '仙台市若林区',
        4104: '仙台市太白区',
        4105: '仙台市泉区',
        4202: '宮城県石巻市',
        4203: '宮城県塩竈市',
        4205: '宮城県気仙沼市',
        4206: '宮城県白石市',
        4207: '宮城県名取市',
        4208: '宮城県角田市',
        4209: '宮城県多賀城市',
        4211: '宮城県岩沼市',
        4212: '宮城県登米市',
        4213: '宮城県栗原市',
        4214: '宮城県東松島市',
        4215: '宮城県大崎市',
        4216: '宮城県富谷市',
        4301: '宮城県蔵王町',
        4302: '宮城県七ヶ宿町',
        4321: '宮城県大河原町',
        4322: '宮城県村田町',
        4323: '宮城県柴田町',
        4324: '宮城県川崎町',
        4341: '宮城県丸森町',
        4361: '宮城県亘理町',
        4362: '宮城県山元町',
        4401: '宮城県松島町',
        4404: '宮城県七ヶ浜町',
        4406: '宮城県利府町',
        4421: '宮城県大和町',
        4422: '宮城県大郷町',
        4424: '宮城県大衡村',
        4444: '宮城県色麻町',
        4445: '宮城県加美町',
        4501: '宮城県涌谷町',
        4505: '宮城県美里町',
        4581: '宮城県女川町',
        4606: '宮城県南三陸町',
        5000: '秋田県',
        5201: '秋田県秋田市',
        5202: '秋田県能代市',
        5203: '秋田県横手市',
        5204: '秋田県大館市',
        5206: '秋田県男鹿市',
        5207: '秋田県湯沢市',
        5209: '秋田県鹿角市',
        5210: '秋田県由利本荘市',
        5211: '秋田県潟上市',
        5212: '秋田県大仙市',
        5213: '秋田県北秋田市',
        5214: '秋田県にかほ市',
        5215: '秋田県仙北市',
        5303: '秋田県小坂町',
        5327: '秋田県上小阿仁村',
        5346: '秋田県藤里町',
        5348: '秋田県三種町',
        5349: '秋田県八峰町',
        5361: '秋田県五城目町',
        5363: '秋田県八郎潟町',
        5366: '秋田県井川町',
        5368: '秋田県大潟村',
        5434: '秋田県美郷町',
        5463: '秋田県羽後町',
        5464: '秋田県東成瀬村',
        6000: '山形県',
        6201: '山形県山形市',
        6202: '山形県米沢市',
        6203: '山形県鶴岡市',
        6204: '山形県酒田市',
        6205: '山形県新庄市',
        6206: '山形県寒河江市',
        6207: '山形県上山市',
        6208: '山形県村山市',
        6209: '山形県長井市',
        6210: '山形県天童市',
        6211: '山形県東根市',
        6212: '山形県尾花沢市',
        6213: '山形県南陽市',
        6301: '山形県山辺町',
        6302: '山形県中山町',
        6321: '山形県河北町',
        6322: '山形県西川町',
        6323: '山形県朝日町',
        6324: '山形県大江町',
        6341: '山形県大石田町',
        6361: '山形県金山町',
        6362: '山形県最上町',
        6363: '山形県舟形町',
        6364: '山形県真室川町',
        6365: '山形県大蔵村',
        6366: '山形県鮭川村',
        6367: '山形県戸沢村',
        6381: '山形県高畠町',
        6382: '山形県川西町',
        6401: '山形県小国町',
        6402: '山形県白鷹町',
        6403: '山形県飯豊町',
        6426: '山形県三川町',
        6428: '山形県庄内町',
        6461: '山形県遊佐町',
        7000: '福島県',
        7201: '福島県福島市',
        7202: '福島県会津若松市',
        7203: '福島県郡山市',
        7204: '福島県いわき市',
        7205: '福島県白河市',
        7207: '福島県須賀川市',
        7208: '福島県喜多方市',
        7209: '福島県相馬市',
        7210: '福島県二本松市',
        7211: '福島県田村市',
        7212: '福島県南相馬市',
        7213: '福島県伊達市',
        7214: '福島県本宮市',
        7301: '福島県桑折町',
        7303: '福島県国見町',
        7308: '福島県川俣町',
        7322: '福島県大玉村',
        7342: '福島県鏡石町',
        7344: '福島県天栄村',
        7362: '福島県下郷町',
        7364: '福島県檜枝岐村',
        7367: '福島県只見町',
        7368: '福島県南会津町',
        7402: '福島県北塩原村',
        7405: '福島県西会津町',
        7407: '福島県磐梯町',
        7408: '福島県猪苗代町',
        7421: '福島県会津坂下町',
        7422: '福島県湯川村',
        7423: '福島県柳津町',
        7444: '福島県三島町',
        7445: '福島県金山町',
        7446: '福島県昭和村',
        7447: '福島県会津美里町',
        7461: '福島県西郷村',
        7464: '福島県泉崎村',
        7465: '福島県中島村',
        7466: '福島県矢吹町',
        7481: '福島県棚倉町',
        7482: '福島県矢祭町',
        7483: '福島県塙町',
        7484: '福島県鮫川村',
        7501: '福島県石川町',
        7502: '福島県玉川村',
        7503: '福島県平田村',
        7504: '福島県浅川町',
        7505: '福島県古殿町',
        7521: '福島県三春町',
        7522: '福島県小野町',
        7541: '福島県広野町',
        7542: '福島県楢葉町',
        7543: '福島県富岡町',
        7544: '福島県川内村',
        7545: '福島県大熊町',
        7546: '福島県双葉町',
        7547: '福島県浪江町',
        7548: '福島県葛尾村',
        7561: '福島県新地町',
        7564: '福島県飯舘村',
        8000: '茨城県',
        8201: '茨城県水戸市',
        8202: '茨城県日立市',
        8203: '茨城県土浦市',
        8204: '茨城県古河市',
        8205: '茨城県石岡市',
        8207: '茨城県結城市',
        8208: '茨城県龍ケ崎市',
        8210: '茨城県下妻市',
        8211: '茨城県常総市',
        8212: '茨城県常陸太田市',
        8214: '茨城県高萩市',
        8215: '茨城県北茨城市',
        8216: '茨城県笠間市',
        8217: '茨城県取手市',
        8219: '茨城県牛久市',
        8220: '茨城県つくば市',
        8221: '茨城県ひたちなか市',
        8222: '茨城県鹿嶋市',
        8223: '茨城県潮来市',
        8224: '茨城県守谷市',
        8225: '茨城県常陸大宮市',
        8226: '茨城県那珂市',
        8227: '茨城県筑西市',
        8228: '茨城県坂東市',
        8229: '茨城県稲敷市',
        8230: '茨城県かすみがうら市',
        8231: '茨城県桜川市',
        8232: '茨城県神栖市',
        8233: '茨城県行方市',
        8234: '茨城県鉾田市',
        8235: '茨城県つくばみらい市',
        8236: '茨城県小美玉市',
        8302: '茨城県茨城町',
        8309: '茨城県大洗町',
        8310: '茨城県城里町',
        8341: '茨城県東海村',
        8364: '茨城県大子町',
        8442: '茨城県美浦村',
        8443: '茨城県阿見町',
        8447: '茨城県河内町',
        8521: '茨城県八千代町',
        8542: '茨城県五霞町',
        8546: '茨城県境町',
        8564: '茨城県利根町',
        9000: '栃木県',
        9201: '栃木県宇都宮市',
        9202: '栃木県足利市',
        9203: '栃木県栃木市',
        9204: '栃木県佐野市',
        9205: '栃木県鹿沼市',
        9206: '栃木県日光市',
        9208: '栃木県小山市',
        9209: '栃木県真岡市',
        9210: '栃木県大田原市',
        9211: '栃木県矢板市',
        9213: '栃木県那須塩原市',
        9214: '栃木県さくら市',
        9215: '栃木県那須烏山市',
        9216: '栃木県下野市',
        9301: '栃木県上三川町',
        9342: '栃木県益子町',
        9343: '栃木県茂木町',
        9344: '栃木県市貝町',
        9345: '栃木県芳賀町',
        9361: '栃木県壬生町',
        9364: '栃木県野木町',
        9384: '栃木県塩谷町',
        9386: '栃木県高根沢町',
        9407: '栃木県那須町',
        9411: '栃木県那珂川町',
        10000: '群馬県',
        10201: '群馬県前橋市',
        10202: '群馬県高崎市',
        10203: '群馬県桐生市',
        10204: '群馬県伊勢崎市',
        10205: '群馬県太田市',
        10206: '群馬県沼田市',
        10207: '群馬県館林市',
        10208: '群馬県渋川市',
        10209: '群馬県藤岡市',
        10210: '群馬県富岡市',
        10211: '群馬県安中市',
        10212: '群馬県みどり市',
        10344: '群馬県榛東村',
        10345: '群馬県吉岡町',
        10366: '群馬県上野村',
        10367: '群馬県神流町',
        10382: '群馬県下仁田町',
        10383: '群馬県南牧村',
        10384: '群馬県甘楽町',
        10421: '群馬県中之条町',
        10424: '群馬県長野原町',
        10425: '群馬県嬬恋村',
        10426: '群馬県草津町',
        10428: '群馬県高山村',
        10429: '群馬県東吾妻町',
        10443: '群馬県片品村',
        10444: '群馬県川場村',
        10448: '群馬県昭和村',
        10449: '群馬県みなかみ町',
        10464: '群馬県玉村町',
        10521: '群馬県板倉町',
        10522: '群馬県明和町',
        10523: '群馬県千代田町',
        10524: '群馬県大泉町',
        10525: '群馬県邑楽町',
        11000: '埼玉県',
        11100: '埼玉県さいたま市',
        11101: 'さいたま市西区',
        11102: 'さいたま市北区',
        11103: 'さいたま市大宮区',
        11104: 'さいたま市見沼区',
        11105: 'さいたま市中央区',
        11106: 'さいたま市桜区',
        11107: 'さいたま市浦和区',
        11108: 'さいたま市南区',
        11109: 'さいたま市緑区',
        11110: 'さいたま市岩槻区',
        11201: '埼玉県川越市',
        11202: '埼玉県熊谷市',
        11203: '埼玉県川口市',
        11206: '埼玉県行田市',
        11207: '埼玉県秩父市',
        11208: '埼玉県所沢市',
        11209: '埼玉県飯能市',
        11210: '埼玉県加須市',
        11211: '埼玉県本庄市',
        11212: '埼玉県東松山市',
        11214: '埼玉県春日部市',
        11215: '埼玉県狭山市',
        11216: '埼玉県羽生市',
        11217: '埼玉県鴻巣市',
        11218: '埼玉県深谷市',
        11219: '埼玉県上尾市',
        11221: '埼玉県草加市',
        11222: '埼玉県越谷市',
        11223: '埼玉県蕨市',
        11224: '埼玉県戸田市',
        11225: '埼玉県入間市',
        11227: '埼玉県朝霞市',
        11228: '埼玉県志木市',
        11229: '埼玉県和光市',
        11230: '埼玉県新座市',
        11231: '埼玉県桶川市',
        11232: '埼玉県久喜市',
        11233: '埼玉県北本市',
        11234: '埼玉県八潮市',
        11235: '埼玉県富士見市',
        11237: '埼玉県三郷市',
        11238: '埼玉県蓮田市',
        11239: '埼玉県坂戸市',
        11240: '埼玉県幸手市',
        11241: '埼玉県鶴ヶ島市',
        11242: '埼玉県日高市',
        11243: '埼玉県吉川市',
        11245: '埼玉県ふじみ野市',
        11246: '埼玉県白岡市',
        11301: '埼玉県伊奈町',
        11324: '埼玉県三芳町',
        11326: '埼玉県毛呂山町',
        11327: '埼玉県越生町',
        11341: '埼玉県滑川町',
        11342: '埼玉県嵐山町',
        11343: '埼玉県小川町',
        11346: '埼玉県川島町',
        11347: '埼玉県吉見町',
        11348: '埼玉県鳩山町',
        11349: '埼玉県ときがわ町',
        11361: '埼玉県横瀬町',
        11362: '埼玉県皆野町',
        11363: '埼玉県長瀞町',
        11365: '埼玉県小鹿野町',
        11369: '埼玉県東秩父村',
        11381: '埼玉県美里町',
        11383: '埼玉県神川町',
        11385: '埼玉県上里町',
        11408: '埼玉県寄居町',
        11442: '埼玉県宮代町',
        11464: '埼玉県杉戸町',
        11465: '埼玉県松伏町',
        12000: '千葉県',
        12100: '千葉県千葉市',
        12101: '千葉市中央区',
        12102: '千葉市花見川区',
        12103: '千葉市稲毛区',
        12104: '千葉市若葉区',
        12105: '千葉市緑区',
        12106: '千葉市美浜区',
        12202: '千葉県銚子市',
        12203: '千葉県市川市',
        12204: '千葉県船橋市',
        12205: '千葉県館山市',
        12206: '千葉県木更津市',
        12207: '千葉県松戸市',
        12208: '千葉県野田市',
        12210: '千葉県茂原市',
        12211: '千葉県成田市',
        12212: '千葉県佐倉市',
        12213: '千葉県東金市',
        12215: '千葉県旭市',
        12216: '千葉県習志野市',
        12217: '千葉県柏市',
        12218: '千葉県勝浦市',
        12219: '千葉県市原市',
        12220: '千葉県流山市',
        12221: '千葉県八千代市',
        12222: '千葉県我孫子市',
        12223: '千葉県鴨川市',
        12224: '千葉県鎌ケ谷市',
        12225: '千葉県君津市',
        12226: '千葉県富津市',
        12227: '千葉県浦安市',
        12228: '千葉県四街道市',
        12229: '千葉県袖ケ浦市',
        12230: '千葉県八街市',
        12231: '千葉県印西市',
        12232: '千葉県白井市',
        12233: '千葉県富里市',
        12234: '千葉県南房総市',
        12235: '千葉県匝瑳市',
        12236: '千葉県香取市',
        12237: '千葉県山武市',
        12238: '千葉県いすみ市',
        12239: '千葉県大網白里市',
        12322: '千葉県酒々井町',
        12329: '千葉県栄町',
        12342: '千葉県神崎町',
        12347: '千葉県多古町',
        12349: '千葉県東庄町',
        12403: '千葉県九十九里町',
        12409: '千葉県芝山町',
        12410: '千葉県横芝光町',
        12421: '千葉県一宮町',
        12422: '千葉県睦沢町',
        12423: '千葉県長生村',
        12424: '千葉県白子町',
        12426: '千葉県長柄町',
        12427: '千葉県長南町',
        12441: '千葉県大多喜町',
        12443: '千葉県御宿町',
        12463: '千葉県鋸南町',
        13000: '東京都',
        13101: '東京都千代田区',
        13102: '東京都中央区',
        13103: '東京都港区',
        13104: '東京都新宿区',
        13105: '東京都文京区',
        13106: '東京都台東区',
        13107: '東京都墨田区',
        13108: '東京都江東区',
        13109: '東京都品川区',
        13110: '東京都目黒区',
        13111: '東京都大田区',
        13112: '東京都世田谷区',
        13113: '東京都渋谷区',
        13114: '東京都中野区',
        13115: '東京都杉並区',
        13116: '東京都豊島区',
        13117: '東京都北区',
        13118: '東京都荒川区',
        13119: '東京都板橋区',
        13120: '東京都練馬区',
        13121: '東京都足立区',
        13122: '東京都葛飾区',
        13123: '東京都江戸川区',
        13201: '東京都八王子市',
        13202: '東京都立川市',
        13203: '東京都武蔵野市',
        13204: '東京都三鷹市',
        13205: '東京都青梅市',
        13206: '東京都府中市',
        13207: '東京都昭島市',
        13208: '東京都調布市',
        13209: '東京都町田市',
        13210: '東京都小金井市',
        13211: '東京都小平市',
        13212: '東京都日野市',
        13213: '東京都東村山市',
        13214: '東京都国分寺市',
        13215: '東京都国立市',
        13218: '東京都福生市',
        13219: '東京都狛江市',
        13220: '東京都東大和市',
        13221: '東京都清瀬市',
        13222: '東京都東久留米市',
        13223: '東京都武蔵村山市',
        13224: '東京都多摩市',
        13225: '東京都稲城市',
        13227: '東京都羽村市',
        13228: '東京都あきる野市',
        13229: '東京都西東京市',
        13303: '東京都瑞穂町',
        13305: '東京都日の出町',
        13307: '東京都檜原村',
        13308: '東京都奥多摩町',
        13361: '東京都大島町',
        13362: '東京都利島村',
        13363: '東京都新島村',
        13364: '東京都神津島村',
        13381: '東京都三宅村',
        13382: '東京都御蔵島村',
        13401: '東京都八丈町',
        13402: '東京都青ヶ島村',
        13421: '東京都小笠原村',
        14000: '神奈川県',
        14100: '神奈川県横浜市',
        14101: '横浜市鶴見区',
        14102: '横浜市神奈川区',
        14103: '横浜市西区',
        14104: '横浜市中区',
        14105: '横浜市南区',
        14106: '横浜市保土ケ谷区',
        14107: '横浜市磯子区',
        14108: '横浜市金沢区',
        14109: '横浜市港北区',
        14110: '横浜市戸塚区',
        14111: '横浜市港南区',
        14112: '横浜市旭区',
        14113: '横浜市緑区',
        14114: '横浜市瀬谷区',
        14115: '横浜市栄区',
        14116: '横浜市泉区',
        14117: '横浜市青葉区',
        14118: '横浜市都筑区',
        14130: '神奈川県川崎市',
        14131: '川崎市川崎区',
        14132: '川崎市幸区',
        14133: '川崎市中原区',
        14134: '川崎市高津区',
        14135: '川崎市多摩区',
        14136: '川崎市宮前区',
        14137: '川崎市麻生区',
        14150: '神奈川県相模原市',
        14151: '相模原市緑区',
        14152: '相模原市中央区',
        14153: '相模原市南区',
        14201: '神奈川県横須賀市',
        14203: '神奈川県平塚市',
        14204: '神奈川県鎌倉市',
        14205: '神奈川県藤沢市',
        14206: '神奈川県小田原市',
        14207: '神奈川県茅ヶ崎市',
        14208: '神奈川県逗子市',
        14210: '神奈川県三浦市',
        14211: '神奈川県秦野市',
        14212: '神奈川県厚木市',
        14213: '神奈川県大和市',
        14214: '神奈川県伊勢原市',
        14215: '神奈川県海老名市',
        14216: '神奈川県座間市',
        14217: '神奈川県南足柄市',
        14218: '神奈川県綾瀬市',
        14301: '神奈川県葉山町',
        14321: '神奈川県寒川町',
        14341: '神奈川県大磯町',
        14342: '神奈川県二宮町',
        14361: '神奈川県中井町',
        14362: '神奈川県大井町',
        14363: '神奈川県松田町',
        14364: '神奈川県山北町',
        14366: '神奈川県開成町',
        14382: '神奈川県箱根町',
        14383: '神奈川県真鶴町',
        14384: '神奈川県湯河原町',
        14401: '神奈川県愛川町',
        14402: '神奈川県清川村',
        15000: '新潟県',
        15100: '新潟県新潟市',
        15101: '新潟市北区',
        15102: '新潟市東区',
        15103: '新潟市中央区',
        15104: '新潟市江南区',
        15105: '新潟市秋葉区',
        15106: '新潟市南区',
        15107: '新潟市西区',
        15108: '新潟市西蒲区',
        15202: '新潟県長岡市',
        15204: '新潟県三条市',
        15205: '新潟県柏崎市',
        15206: '新潟県新発田市',
        15208: '新潟県小千谷市',
        15209: '新潟県加茂市',
        15210: '新潟県十日町市',
        15211: '新潟県見附市',
        15212: '新潟県村上市',
        15213: '新潟県燕市',
        15216: '新潟県糸魚川市',
        15217: '新潟県妙高市',
        15218: '新潟県五泉市',
        15222: '新潟県上越市',
        15223: '新潟県阿賀野市',
        15224: '新潟県佐渡市',
        15225: '新潟県魚沼市',
        15226: '新潟県南魚沼市',
        15227: '新潟県胎内市',
        15307: '新潟県聖籠町',
        15342: '新潟県弥彦村',
        15361: '新潟県田上町',
        15385: '新潟県阿賀町',
        15405: '新潟県出雲崎町',
        15461: '新潟県湯沢町',
        15482: '新潟県津南町',
        15504: '新潟県刈羽村',
        15581: '新潟県関川村',
        15586: '新潟県粟島浦村',
        16000: '富山県',
        16201: '富山県富山市',
        16202: '富山県高岡市',
        16204: '富山県魚津市',
        16205: '富山県氷見市',
        16206: '富山県滑川市',
        16207: '富山県黒部市',
        16208: '富山県砺波市',
        16209: '富山県小矢部市',
        16210: '富山県南砺市',
        16211: '富山県射水市',
        16321: '富山県舟橋村',
        16322: '富山県上市町',
        16323: '富山県立山町',
        16342: '富山県入善町',
        16343: '富山県朝日町',
        17000: '石川県',
        17201: '石川県金沢市',
        17202: '石川県七尾市',
        17203: '石川県小松市',
        17204: '石川県輪島市',
        17205: '石川県珠洲市',
        17206: '石川県加賀市',
        17207: '石川県羽咋市',
        17209: '石川県かほく市',
        17210: '石川県白山市',
        17211: '石川県能美市',
        17212: '石川県野々市市',
        17324: '石川県川北町',
        17361: '石川県津幡町',
        17365: '石川県内灘町',
        17384: '石川県志賀町',
        17386: '石川県宝達志水町',
        17407: '石川県中能登町',
        17461: '石川県穴水町',
        17463: '石川県能登町',
        18000: '福井県',
        18201: '福井県福井市',
        18202: '福井県敦賀市',
        18204: '福井県小浜市',
        18205: '福井県大野市',
        18206: '福井県勝山市',
        18207: '福井県鯖江市',
        18208: '福井県あわら市',
        18209: '福井県越前市',
        18210: '福井県坂井市',
        18322: '福井県永平寺町',
        18382: '福井県池田町',
        18404: '福井県南越前町',
        18423: '福井県越前町',
        18442: '福井県美浜町',
        18481: '福井県高浜町',
        18483: '福井県おおい町',
        18501: '福井県若狭町',
        19000: '山梨県',
        19201: '山梨県甲府市',
        19202: '山梨県富士吉田市',
        19204: '山梨県都留市',
        19205: '山梨県山梨市',
        19206: '山梨県大月市',
        19207: '山梨県韮崎市',
        19208: '山梨県南アルプス市',
        19209: '山梨県北杜市',
        19210: '山梨県甲斐市',
        19211: '山梨県笛吹市',
        19212: '山梨県上野原市',
        19213: '山梨県甲州市',
        19214: '山梨県中央市',
        19346: '山梨県市川三郷町',
        19364: '山梨県早川町',
        19365: '山梨県身延町',
        19366: '山梨県南部町',
        19368: '山梨県富士川町',
        19384: '山梨県昭和町',
        19422: '山梨県道志村',
        19423: '山梨県西桂町',
        19424: '山梨県忍野村',
        19425: '山梨県山中湖村',
        19429: '山梨県鳴沢村',
        19430: '山梨県富士河口湖町',
        19442: '山梨県小菅村',
        19443: '山梨県丹波山村',
        20000: '長野県',
        20201: '長野県長野市',
        20202: '長野県松本市',
        20203: '長野県上田市',
        20204: '長野県岡谷市',
        20205: '長野県飯田市',
        20206: '長野県諏訪市',
        20207: '長野県須坂市',
        20208: '長野県小諸市',
        20209: '長野県伊那市',
        20210: '長野県駒ヶ根市',
        20211: '長野県中野市',
        20212: '長野県大町市',
        20213: '長野県飯山市',
        20214: '長野県茅野市',
        20215: '長野県塩尻市',
        20217: '長野県佐久市',
        20218: '長野県千曲市',
        20219: '長野県東御市',
        20220: '長野県安曇野市',
        20303: '長野県小海町',
        20304: '長野県川上村',
        20305: '長野県南牧村',
        20306: '長野県南相木村',
        20307: '長野県北相木村',
        20309: '長野県佐久穂町',
        20321: '長野県軽井沢町',
        20323: '長野県御代田町',
        20324: '長野県立科町',
        20349: '長野県青木村',
        20350: '長野県長和町',
        20361: '長野県下諏訪町',
        20362: '長野県富士見町',
        20363: '長野県原村',
        20382: '長野県辰野町',
        20383: '長野県箕輪町',
        20384: '長野県飯島町',
        20385: '長野県南箕輪村',
        20386: '長野県中川村',
        20388: '長野県宮田村',
        20402: '長野県松川町',
        20403: '長野県高森町',
        20404: '長野県阿南町',
        20407: '長野県阿智村',
        20409: '長野県平谷村',
        20410: '長野県根羽村',
        20411: '長野県下條村',
        20412: '長野県売木村',
        20413: '長野県天龍村',
        20414: '長野県泰阜村',
        20415: '長野県喬木村',
        20416: '長野県豊丘村',
        20417: '長野県大鹿村',
        20422: '長野県上松町',
        20423: '長野県南木曽町',
        20425: '長野県木祖村',
        20429: '長野県王滝村',
        20430: '長野県大桑村',
        20432: '長野県木曽町',
        20446: '長野県麻績村',
        20448: '長野県生坂村',
        20450: '長野県山形村',
        20451: '長野県朝日村',
        20452: '長野県筑北村',
        20481: '長野県池田町',
        20482: '長野県松川村',
        20485: '長野県白馬村',
        20486: '長野県小谷村',
        20521: '長野県坂城町',
        20541: '長野県小布施町',
        20543: '長野県高山村',
        20561: '長野県山ノ内町',
        20562: '長野県木島平村',
        20563: '長野県野沢温泉村',
        20583: '長野県信濃町',
        20588: '長野県小川村',
        20590: '長野県飯綱町',
        20602: '長野県栄村',
        21000: '岐阜県',
        21201: '岐阜県岐阜市',
        21202: '岐阜県大垣市',
        21203: '岐阜県高山市',
        21204: '岐阜県多治見市',
        21205: '岐阜県関市',
        21206: '岐阜県中津川市',
        21207: '岐阜県美濃市',
        21208: '岐阜県瑞浪市',
        21209: '岐阜県羽島市',
        21210: '岐阜県恵那市',
        21211: '岐阜県美濃加茂市',
        21212: '岐阜県土岐市',
        21213: '岐阜県各務原市',
        21214: '岐阜県可児市',
        21215: '岐阜県山県市',
        21216: '岐阜県瑞穂市',
        21217: '岐阜県飛騨市',
        21218: '岐阜県本巣市',
        21219: '岐阜県郡上市',
        21220: '岐阜県下呂市',
        21221: '岐阜県海津市',
        21302: '岐阜県岐南町',
        21303: '岐阜県笠松町',
        21341: '岐阜県養老町',
        21361: '岐阜県垂井町',
        21362: '岐阜県関ケ原町',
        21381: '岐阜県神戸町',
        21382: '岐阜県輪之内町',
        21383: '岐阜県安八町',
        21401: '岐阜県揖斐川町',
        21403: '岐阜県大野町',
        21404: '岐阜県池田町',
        21421: '岐阜県北方町',
        21501: '岐阜県坂祝町',
        21502: '岐阜県富加町',
        21503: '岐阜県川辺町',
        21504: '岐阜県七宗町',
        21505: '岐阜県八百津町',
        21506: '岐阜県白川町',
        21507: '岐阜県東白川村',
        21521: '岐阜県御嵩町',
        21604: '岐阜県白川村',
        22000: '静岡県',
        22100: '静岡県静岡市',
        22101: '静岡市葵区',
        22102: '静岡市駿河区',
        22103: '静岡市清水区',
        22130: '静岡県浜松市',
        22131: '浜松市中区',
        22132: '浜松市東区',
        22133: '浜松市西区',
        22134: '浜松市南区',
        22135: '浜松市北区',
        22136: '浜松市浜北区',
        22137: '浜松市天竜区',
        22138: '浜松市中央区',
        22139: '浜松市浜名区',
        22140: '浜松市天竜区',
        22203: '静岡県沼津市',
        22205: '静岡県熱海市',
        22206: '静岡県三島市',
        22207: '静岡県富士宮市',
        22208: '静岡県伊東市',
        22209: '静岡県島田市',
        22210: '静岡県富士市',
        22211: '静岡県磐田市',
        22212: '静岡県焼津市',
        22213: '静岡県掛川市',
        22214: '静岡県藤枝市',
        22215: '静岡県御殿場市',
        22216: '静岡県袋井市',
        22219: '静岡県下田市',
        22220: '静岡県裾野市',
        22221: '静岡県湖西市',
        22222: '静岡県伊豆市',
        22223: '静岡県御前崎市',
        22224: '静岡県菊川市',
        22225: '静岡県伊豆の国市',
        22226: '静岡県牧之原市',
        22301: '静岡県東伊豆町',
        22302: '静岡県河津町',
        22304: '静岡県南伊豆町',
        22305: '静岡県松崎町',
        22306: '静岡県西伊豆町',
        22325: '静岡県函南町',
        22341: '静岡県清水町',
        22342: '静岡県長泉町',
        22344: '静岡県小山町',
        22424: '静岡県吉田町',
        22429: '静岡県川根本町',
        22461: '静岡県森町',
        23000: '愛知県',
        23100: '愛知県名古屋市',
        23101: '名古屋市千種区',
        23102: '名古屋市東区',
        23103: '名古屋市北区',
        23104: '名古屋市西区',
        23105: '名古屋市中村区',
        23106: '名古屋市中区',
        23107: '名古屋市昭和区',
        23108: '名古屋市瑞穂区',
        23109: '名古屋市熱田区',
        23110: '名古屋市中川区',
        23111: '名古屋市港区',
        23112: '名古屋市南区',
        23113: '名古屋市守山区',
        23114: '名古屋市緑区',
        23115: '名古屋市名東区',
        23116: '名古屋市天白区',
        23201: '愛知県豊橋市',
        23202: '愛知県岡崎市',
        23203: '愛知県一宮市',
        23204: '愛知県瀬戸市',
        23205: '愛知県半田市',
        23206: '愛知県春日井市',
        23207: '愛知県豊川市',
        23208: '愛知県津島市',
        23209: '愛知県碧南市',
        23210: '愛知県刈谷市',
        23211: '愛知県豊田市',
        23212: '愛知県安城市',
        23213: '愛知県西尾市',
        23214: '愛知県蒲郡市',
        23215: '愛知県犬山市',
        23216: '愛知県常滑市',
        23217: '愛知県江南市',
        23219: '愛知県小牧市',
        23220: '愛知県稲沢市',
        23221: '愛知県新城市',
        23222: '愛知県東海市',
        23223: '愛知県大府市',
        23224: '愛知県知多市',
        23225: '愛知県知立市',
        23226: '愛知県尾張旭市',
        23227: '愛知県高浜市',
        23228: '愛知県岩倉市',
        23229: '愛知県豊明市',
        23230: '愛知県日進市',
        23231: '愛知県田原市',
        23232: '愛知県愛西市',
        23233: '愛知県清須市',
        23234: '愛知県北名古屋市',
        23235: '愛知県弥富市',
        23236: '愛知県みよし市',
        23237: '愛知県あま市',
        23238: '愛知県長久手市',
        23302: '愛知県東郷町',
        23342: '愛知県豊山町',
        23361: '愛知県大口町',
        23362: '愛知県扶桑町',
        23424: '愛知県大治町',
        23425: '愛知県蟹江町',
        23427: '愛知県飛島村',
        23441: '愛知県阿久比町',
        23442: '愛知県東浦町',
        23445: '愛知県南知多町',
        23446: '愛知県美浜町',
        23447: '愛知県武豊町',
        23501: '愛知県幸田町',
        23561: '愛知県設楽町',
        23562: '愛知県東栄町',
        23563: '愛知県豊根村',
        24000: '三重県',
        24201: '三重県津市',
        24202: '三重県四日市市',
        24203: '三重県伊勢市',
        24204: '三重県松阪市',
        24205: '三重県桑名市',
        24207: '三重県鈴鹿市',
        24208: '三重県名張市',
        24209: '三重県尾鷲市',
        24210: '三重県亀山市',
        24211: '三重県鳥羽市',
        24212: '三重県熊野市',
        24214: '三重県いなべ市',
        24215: '三重県志摩市',
        24216: '三重県伊賀市',
        24303: '三重県木曽岬町',
        24324: '三重県東員町',
        24341: '三重県菰野町',
        24343: '三重県朝日町',
        24344: '三重県川越町',
        24441: '三重県多気町',
        24442: '三重県明和町',
        24443: '三重県大台町',
        24461: '三重県玉城町',
        24470: '三重県度会町',
        24471: '三重県大紀町',
        24472: '三重県南伊勢町',
        24543: '三重県紀北町',
        24561: '三重県御浜町',
        24562: '三重県紀宝町',
        25000: '滋賀県',
        25201: '滋賀県大津市',
        25202: '滋賀県彦根市',
        25203: '滋賀県長浜市',
        25204: '滋賀県近江八幡市',
        25206: '滋賀県草津市',
        25207: '滋賀県守山市',
        25208: '滋賀県栗東市',
        25209: '滋賀県甲賀市',
        25210: '滋賀県野洲市',
        25211: '滋賀県湖南市',
        25212: '滋賀県高島市',
        25213: '滋賀県東近江市',
        25214: '滋賀県米原市',
        25383: '滋賀県日野町',
        25384: '滋賀県竜王町',
        25425: '滋賀県愛荘町',
        25441: '滋賀県豊郷町',
        25442: '滋賀県甲良町',
        25443: '滋賀県多賀町',
        26000: '京都府',
        26100: '京都府京都市',
        26101: '京都市北区',
        26102: '京都市上京区',
        26103: '京都市左京区',
        26104: '京都市中京区',
        26105: '京都市東山区',
        26106: '京都市下京区',
        26107: '京都市南区',
        26108: '京都市右京区',
        26109: '京都市伏見区',
        26110: '京都市山科区',
        26111: '京都市西京区',
        26201: '京都府福知山市',
        26202: '京都府舞鶴市',
        26203: '京都府綾部市',
        26204: '京都府宇治市',
        26205: '京都府宮津市',
        26206: '京都府亀岡市',
        26207: '京都府城陽市',
        26208: '京都府向日市',
        26209: '京都府長岡京市',
        26210: '京都府八幡市',
        26211: '京都府京田辺市',
        26212: '京都府京丹後市',
        26213: '京都府南丹市',
        26214: '京都府木津川市',
        26303: '京都府大山崎町',
        26322: '京都府久御山町',
        26343: '京都府井手町',
        26344: '京都府宇治田原町',
        26364: '京都府笠置町',
        26365: '京都府和束町',
        26366: '京都府精華町',
        26367: '京都府南山城村',
        26407: '京都府京丹波町',
        26463: '京都府伊根町',
        26465: '京都府与謝野町',
        27000: '大阪府',
        27100: '大阪府大阪市',
        27101: '大阪市北区',
        27102: '大阪市都島区',
        27103: '大阪市福島区',
        27104: '大阪市此花区',
        27105: '大阪市東区',
        27106: '大阪市西区',
        27107: '大阪市港区',
        27108: '大阪市大正区',
        27109: '大阪市天王寺区',
        27110: '大阪市南区',
        27111: '大阪市浪速区',
        27112: '大阪市大淀区',
        27113: '大阪市西淀川区',
        27114: '大阪市東淀川区',
        27115: '大阪市東成区',
        27116: '大阪市生野区',
        27117: '大阪市旭区',
        27118: '大阪市城東区',
        27119: '大阪市阿倍野区',
        27120: '大阪市住吉区',
        27121: '大阪市東住吉区',
        27122: '大阪市西成区',
        27123: '大阪市淀川区',
        27124: '大阪市鶴見区',
        27125: '大阪市住之江区',
        27126: '大阪市平野区',
        27127: '大阪市北区',
        27128: '大阪市中央区',
        27140: '大阪府堺市',
        27141: '堺市堺区',
        27142: '堺市中区',
        27143: '堺市東区',
        27144: '堺市西区',
        27145: '堺市南区',
        27146: '堺市北区',
        27147: '堺市美原区',
        27202: '大阪府岸和田市',
        27203: '大阪府豊中市',
        27204: '大阪府池田市',
        27205: '大阪府吹田市',
        27206: '大阪府泉大津市',
        27207: '大阪府高槻市',
        27208: '大阪府貝塚市',
        27209: '大阪府守口市',
        27210: '大阪府枚方市',
        27211: '大阪府茨木市',
        27212: '大阪府八尾市',
        27213: '大阪府泉佐野市',
        27214: '大阪府富田林市',
        27215: '大阪府寝屋川市',
        27216: '大阪府河内長野市',
        27217: '大阪府松原市',
        27218: '大阪府大東市',
        27219: '大阪府和泉市',
        27220: '大阪府箕面市',
        27221: '大阪府柏原市',
        27222: '大阪府羽曳野市',
        27223: '大阪府門真市',
        27224: '大阪府摂津市',
        27225: '大阪府高石市',
        27226: '大阪府藤井寺市',
        27227: '大阪府東大阪市',
        27228: '大阪府泉南市',
        27229: '大阪府四條畷市',
        27230: '大阪府交野市',
        27231: '大阪府大阪狭山市',
        27232: '大阪府阪南市',
        27301: '大阪府島本町',
        27321: '大阪府豊能町',
        27322: '大阪府能勢町',
        27341: '大阪府忠岡町',
        27361: '大阪府熊取町',
        27362: '大阪府田尻町',
        27366: '大阪府岬町',
        27381: '大阪府太子町',
        27382: '大阪府河南町',
        27383: '大阪府千早赤阪村',
        28000: '兵庫県',
        28100: '兵庫県神戸市',
        28101: '神戸市東灘区',
        28102: '神戸市灘区',
        28103: '神戸市葺合区',
        28104: '神戸市生田区',
        28105: '神戸市兵庫区',
        28106: '神戸市長田区',
        28107: '神戸市須磨区',
        28108: '神戸市垂水区',
        28109: '神戸市北区',
        28110: '神戸市中央区',
        28111: '神戸市西区',
        28201: '兵庫県姫路市',
        28202: '兵庫県尼崎市',
        28203: '兵庫県明石市',
        28204: '兵庫県西宮市',
        28205: '兵庫県洲本市',
        28206: '兵庫県芦屋市',
        28207: '兵庫県伊丹市',
        28208: '兵庫県相生市',
        28209: '兵庫県豊岡市',
        28210: '兵庫県加古川市',
        28212: '兵庫県赤穂市',
        28213: '兵庫県西脇市',
        28214: '兵庫県宝塚市',
        28215: '兵庫県三木市',
        28216: '兵庫県高砂市',
        28217: '兵庫県川西市',
        28218: '兵庫県小野市',
        28219: '兵庫県三田市',
        28220: '兵庫県加西市',
        28221: '兵庫県丹波篠山市',
        28222: '兵庫県養父市',
        28223: '兵庫県丹波市',
        28224: '兵庫県南あわじ市',
        28225: '兵庫県朝来市',
        28226: '兵庫県淡路市',
        28227: '兵庫県宍粟市',
        28228: '兵庫県加東市',
        28229: '兵庫県たつの市',
        28301: '兵庫県猪名川町',
        28365: '兵庫県多可町',
        28381: '兵庫県稲美町',
        28382: '兵庫県播磨町',
        28442: '兵庫県市川町',
        28443: '兵庫県福崎町',
        28446: '兵庫県神河町',
        28464: '兵庫県太子町',
        28481: '兵庫県上郡町',
        28501: '兵庫県佐用町',
        28585: '兵庫県香美町',
        28586: '兵庫県新温泉町',
        29000: '奈良県',
        29201: '奈良県奈良市',
        29202: '奈良県大和高田市',
        29203: '奈良県大和郡山市',
        29204: '奈良県天理市',
        29205: '奈良県橿原市',
        29206: '奈良県桜井市',
        29207: '奈良県五條市',
        29208: '奈良県御所市',
        29209: '奈良県生駒市',
        29210: '奈良県香芝市',
        29211: '奈良県葛城市',
        29212: '奈良県宇陀市',
        29322: '奈良県山添村',
        29342: '奈良県平群町',
        29343: '奈良県三郷町',
        29344: '奈良県斑鳩町',
        29345: '奈良県安堵町',
        29361: '奈良県川西町',
        29362: '奈良県三宅町',
        29363: '奈良県田原本町',
        29385: '奈良県曽爾村',
        29386: '奈良県御杖村',
        29401: '奈良県高取町',
        29402: '奈良県明日香村',
        29424: '奈良県上牧町',
        29425: '奈良県王寺町',
        29426: '奈良県広陵町',
        29427: '奈良県河合町',
        29441: '奈良県吉野町',
        29442: '奈良県大淀町',
        29443: '奈良県下市町',
        29444: '奈良県黒滝村',
        29446: '奈良県天川村',
        29447: '奈良県野迫川村',
        29449: '奈良県十津川村',
        29450: '奈良県下北山村',
        29451: '奈良県上北山村',
        29452: '奈良県川上村',
        29453: '奈良県東吉野村',
        30000: '和歌山県',
        30201: '和歌山県和歌山市',
        30202: '和歌山県海南市',
        30203: '和歌山県橋本市',
        30204: '和歌山県有田市',
        30205: '和歌山県御坊市',
        30206: '和歌山県田辺市',
        30207: '和歌山県新宮市',
        30208: '和歌山県紀の川市',
        30209: '和歌山県岩出市',
        30304: '和歌山県紀美野町',
        30341: '和歌山県かつらぎ町',
        30343: '和歌山県九度山町',
        30344: '和歌山県高野町',
        30361: '和歌山県湯浅町',
        30362: '和歌山県広川町',
        30366: '和歌山県有田川町',
        30381: '和歌山県美浜町',
        30382: '和歌山県日高町',
        30383: '和歌山県由良町',
        30390: '和歌山県印南町',
        30391: '和歌山県みなべ町',
        30392: '和歌山県日高川町',
        30401: '和歌山県白浜町',
        30404: '和歌山県上富田町',
        30406: '和歌山県すさみ町',
        30421: '和歌山県那智勝浦町',
        30422: '和歌山県太地町',
        30424: '和歌山県古座川町',
        30427: '和歌山県北山村',
        30428: '和歌山県串本町',
        31000: '鳥取県',
        31201: '鳥取県鳥取市',
        31202: '鳥取県米子市',
        31203: '鳥取県倉吉市',
        31204: '鳥取県境港市',
        31302: '鳥取県岩美町',
        31325: '鳥取県若桜町',
        31328: '鳥取県智頭町',
        31329: '鳥取県八頭町',
        31364: '鳥取県三朝町',
        31370: '鳥取県湯梨浜町',
        31371: '鳥取県琴浦町',
        31372: '鳥取県北栄町',
        31384: '鳥取県日吉津村',
        31386: '鳥取県大山町',
        31389: '鳥取県南部町',
        31390: '鳥取県伯耆町',
        31401: '鳥取県日南町',
        31402: '鳥取県日野町',
        31403: '鳥取県江府町',
        32000: '島根県',
        32201: '島根県松江市',
        32202: '島根県浜田市',
        32203: '島根県出雲市',
        32204: '島根県益田市',
        32205: '島根県大田市',
        32206: '島根県安来市',
        32207: '島根県江津市',
        32209: '島根県雲南市',
        32343: '島根県奥出雲町',
        32386: '島根県飯南町',
        32441: '島根県川本町',
        32448: '島根県美郷町',
        32449: '島根県邑南町',
        32501: '島根県津和野町',
        32505: '島根県吉賀町',
        32525: '島根県海士町',
        32526: '島根県西ノ島町',
        32527: '島根県知夫村',
        32528: '島根県隠岐の島町',
        33000: '岡山県',
        33100: '岡山県岡山市',
        33101: '岡山市北区',
        33102: '岡山市中区',
        33103: '岡山市東区',
        33104: '岡山市南区',
        33202: '岡山県倉敷市',
        33203: '岡山県津山市',
        33204: '岡山県玉野市',
        33205: '岡山県笠岡市',
        33207: '岡山県井原市',
        33208: '岡山県総社市',
        33209: '岡山県高梁市',
        33210: '岡山県新見市',
        33211: '岡山県備前市',
        33212: '岡山県瀬戸内市',
        33213: '岡山県赤磐市',
        33214: '岡山県真庭市',
        33215: '岡山県美作市',
        33216: '岡山県浅口市',
        33346: '岡山県和気町',
        33423: '岡山県早島町',
        33445: '岡山県里庄町',
        33461: '岡山県矢掛町',
        33586: '岡山県新庄村',
        33606: '岡山県鏡野町',
        33622: '岡山県勝央町',
        33623: '岡山県奈義町',
        33643: '岡山県西粟倉村',
        33663: '岡山県久米南町',
        33666: '岡山県美咲町',
        33681: '岡山県吉備中央町',
        34000: '広島県',
        34100: '広島県広島市',
        34101: '広島市中区',
        34102: '広島市東区',
        34103: '広島市南区',
        34104: '広島市西区',
        34105: '広島市安佐南区',
        34106: '広島市安佐北区',
        34107: '広島市安芸区',
        34108: '広島市佐伯区',
        34202: '広島県呉市',
        34203: '広島県竹原市',
        34204: '広島県三原市',
        34205: '広島県尾道市',
        34207: '広島県福山市',
        34208: '広島県府中市',
        34209: '広島県三次市',
        34210: '広島県庄原市',
        34211: '広島県大竹市',
        34212: '広島県東広島市',
        34213: '広島県廿日市市',
        34214: '広島県安芸高田市',
        34215: '広島県江田島市',
        34302: '広島県府中町',
        34304: '広島県海田町',
        34307: '広島県熊野町',
        34309: '広島県坂町',
        34368: '広島県安芸太田町',
        34369: '広島県北広島町',
        34431: '広島県大崎上島町',
        34462: '広島県世羅町',
        34545: '広島県神石高原町',
        35000: '山口県',
        35201: '山口県下関市',
        35202: '山口県宇部市',
        35203: '山口県山口市',
        35204: '山口県萩市',
        35206: '山口県防府市',
        35207: '山口県下松市',
        35208: '山口県岩国市',
        35210: '山口県光市',
        35211: '山口県長門市',
        35212: '山口県柳井市',
        35213: '山口県美祢市',
        35215: '山口県周南市',
        35216: '山口県山陽小野田市',
        35305: '山口県周防大島町',
        35321: '山口県和木町',
        35341: '山口県上関町',
        35343: '山口県田布施町',
        35344: '山口県平生町',
        35502: '山口県阿武町',
        36000: '徳島県',
        36201: '徳島県徳島市',
        36202: '徳島県鳴門市',
        36203: '徳島県小松島市',
        36204: '徳島県阿南市',
        36205: '徳島県吉野川市',
        36206: '徳島県阿波市',
        36207: '徳島県美馬市',
        36208: '徳島県三好市',
        36301: '徳島県勝浦町',
        36302: '徳島県上勝町',
        36321: '徳島県佐那河内村',
        36341: '徳島県石井町',
        36342: '徳島県神山町',
        36368: '徳島県那賀町',
        36383: '徳島県牟岐町',
        36387: '徳島県美波町',
        36388: '徳島県海陽町',
        36401: '徳島県松茂町',
        36402: '徳島県北島町',
        36403: '徳島県藍住町',
        36404: '徳島県板野町',
        36405: '徳島県上板町',
        36468: '徳島県つるぎ町',
        36489: '徳島県東みよし町',
        37000: '香川県',
        37201: '香川県高松市',
        37202: '香川県丸亀市',
        37203: '香川県坂出市',
        37204: '香川県善通寺市',
        37205: '香川県観音寺市',
        37206: '香川県さぬき市',
        37207: '香川県東かがわ市',
        37208: '香川県三豊市',
        37322: '香川県土庄町',
        37324: '香川県小豆島町',
        37341: '香川県三木町',
        37364: '香川県直島町',
        37386: '香川県宇多津町',
        37387: '香川県綾川町',
        37403: '香川県琴平町',
        37404: '香川県多度津町',
        37406: '香川県まんのう町',
        38000: '愛媛県',
        38201: '愛媛県松山市',
        38202: '愛媛県今治市',
        38203: '愛媛県宇和島市',
        38204: '愛媛県八幡浜市',
        38205: '愛媛県新居浜市',
        38206: '愛媛県西条市',
        38207: '愛媛県大洲市',
        38210: '愛媛県伊予市',
        38213: '愛媛県四国中央市',
        38214: '愛媛県西予市',
        38215: '愛媛県東温市',
        38356: '愛媛県上島町',
        38386: '愛媛県久万高原町',
        38401: '愛媛県松前町',
        38402: '愛媛県砥部町',
        38422: '愛媛県内子町',
        38442: '愛媛県伊方町',
        38484: '愛媛県松野町',
        38488: '愛媛県鬼北町',
        38506: '愛媛県愛南町',
        39000: '高知県',
        39201: '高知県高知市',
        39202: '高知県室戸市',
        39203: '高知県安芸市',
        39204: '高知県南国市',
        39205: '高知県土佐市',
        39206: '高知県須崎市',
        39208: '高知県宿毛市',
        39209: '高知県土佐清水市',
        39210: '高知県四万十市',
        39211: '高知県香南市',
        39212: '高知県香美市',
        39301: '高知県東洋町',
        39302: '高知県奈半利町',
        39303: '高知県田野町',
        39304: '高知県安田町',
        39305: '高知県北川村',
        39306: '高知県馬路村',
        39307: '高知県芸西村',
        39341: '高知県本山町',
        39344: '高知県大豊町',
        39363: '高知県土佐町',
        39364: '高知県大川村',
        39386: '高知県いの町',
        39387: '高知県仁淀川町',
        39401: '高知県中土佐町',
        39402: '高知県佐川町',
        39403: '高知県越知町',
        39405: '高知県梼原町',
        39410: '高知県日高村',
        39411: '高知県津野町',
        39412: '高知県四万十町',
        39424: '高知県大月町',
        39427: '高知県三原村',
        39428: '高知県黒潮町',
        40000: '福岡県',
        40100: '福岡県北九州市',
        40101: '北九州市門司区',
        40102: '北九州市小倉区',
        40103: '北九州市若松区',
        40104: '北九州市八幡区',
        40105: '北九州市戸畑区',
        40106: '北九州市小倉北区',
        40107: '北九州市小倉南区',
        40108: '北九州市八幡東区',
        40109: '北九州市八幡西区',
        40130: '福岡県福岡市',
        40131: '福岡市東区',
        40132: '福岡市博多区',
        40133: '福岡市中央区',
        40134: '福岡市南区',
        40135: '福岡市西区',
        40136: '福岡市城南区',
        40137: '福岡市早良区',
        40202: '福岡県大牟田市',
        40203: '福岡県久留米市',
        40204: '福岡県直方市',
        40205: '福岡県飯塚市',
        40206: '福岡県田川市',
        40207: '福岡県柳川市',
        40210: '福岡県八女市',
        40211: '福岡県筑後市',
        40212: '福岡県大川市',
        40213: '福岡県行橋市',
        40214: '福岡県豊前市',
        40215: '福岡県中間市',
        40216: '福岡県小郡市',
        40217: '福岡県筑紫野市',
        40218: '福岡県春日市',
        40219: '福岡県大野城市',
        40220: '福岡県宗像市',
        40221: '福岡県太宰府市',
        40223: '福岡県古賀市',
        40224: '福岡県福津市',
        40225: '福岡県うきは市',
        40226: '福岡県宮若市',
        40227: '福岡県嘉麻市',
        40228: '福岡県朝倉市',
        40229: '福岡県みやま市',
        40230: '福岡県糸島市',
        40231: '福岡県那珂川市',
        40341: '福岡県宇美町',
        40342: '福岡県篠栗町',
        40343: '福岡県志免町',
        40344: '福岡県須恵町',
        40345: '福岡県新宮町',
        40348: '福岡県久山町',
        40349: '福岡県粕屋町',
        40381: '福岡県芦屋町',
        40382: '福岡県水巻町',
        40383: '福岡県岡垣町',
        40384: '福岡県遠賀町',
        40401: '福岡県小竹町',
        40402: '福岡県鞍手町',
        40421: '福岡県桂川町',
        40447: '福岡県筑前町',
        40448: '福岡県東峰村',
        40503: '福岡県大刀洗町',
        40522: '福岡県大木町',
        40544: '福岡県広川町',
        40601: '福岡県香春町',
        40602: '福岡県添田町',
        40604: '福岡県糸田町',
        40605: '福岡県川崎町',
        40608: '福岡県大任町',
        40609: '福岡県赤村',
        40610: '福岡県福智町',
        40621: '福岡県苅田町',
        40625: '福岡県みやこ町',
        40642: '福岡県吉富町',
        40646: '福岡県上毛町',
        40647: '福岡県築上町',
        41000: '佐賀県',
        41201: '佐賀県佐賀市',
        41202: '佐賀県唐津市',
        41203: '佐賀県鳥栖市',
        41204: '佐賀県多久市',
        41205: '佐賀県伊万里市',
        41206: '佐賀県武雄市',
        41207: '佐賀県鹿島市',
        41208: '佐賀県小城市',
        41209: '佐賀県嬉野市',
        41210: '佐賀県神埼市',
        41327: '佐賀県吉野ヶ里町',
        41341: '佐賀県基山町',
        41345: '佐賀県上峰町',
        41346: '佐賀県みやき町',
        41387: '佐賀県玄海町',
        41401: '佐賀県有田町',
        41423: '佐賀県大町町',
        41424: '佐賀県江北町',
        41425: '佐賀県白石町',
        41441: '佐賀県太良町',
        42000: '長崎県',
        42201: '長崎県長崎市',
        42202: '長崎県佐世保市',
        42203: '長崎県島原市',
        42204: '長崎県諫早市',
        42205: '長崎県大村市',
        42207: '長崎県平戸市',
        42208: '長崎県松浦市',
        42209: '長崎県対馬市',
        42210: '長崎県壱岐市',
        42211: '長崎県五島市',
        42212: '長崎県西海市',
        42213: '長崎県雲仙市',
        42214: '長崎県南島原市',
        42307: '長崎県長与町',
        42308: '長崎県時津町',
        42321: '長崎県東彼杵町',
        42322: '長崎県川棚町',
        42323: '長崎県波佐見町',
        42383: '長崎県小値賀町',
        42391: '長崎県佐々町',
        42411: '長崎県新上五島町',
        43000: '熊本県',
        43100: '熊本県熊本市',
        43101: '熊本市中央区',
        43102: '熊本市東区',
        43103: '熊本市西区',
        43104: '熊本市南区',
        43105: '熊本市北区',
        43202: '熊本県八代市',
        43203: '熊本県人吉市',
        43204: '熊本県荒尾市',
        43205: '熊本県水俣市',
        43206: '熊本県玉名市',
        43208: '熊本県山鹿市',
        43210: '熊本県菊池市',
        43211: '熊本県宇土市',
        43212: '熊本県上天草市',
        43213: '熊本県宇城市',
        43214: '熊本県阿蘇市',
        43215: '熊本県天草市',
        43216: '熊本県合志市',
        43348: '熊本県美里町',
        43364: '熊本県玉東町',
        43367: '熊本県南関町',
        43368: '熊本県長洲町',
        43369: '熊本県和水町',
        43403: '熊本県大津町',
        43404: '熊本県菊陽町',
        43423: '熊本県南小国町',
        43424: '熊本県小国町',
        43425: '熊本県産山村',
        43428: '熊本県高森町',
        43432: '熊本県西原村',
        43433: '熊本県南阿蘇村',
        43441: '熊本県御船町',
        43442: '熊本県嘉島町',
        43443: '熊本県益城町',
        43444: '熊本県甲佐町',
        43447: '熊本県山都町',
        43468: '熊本県氷川町',
        43482: '熊本県芦北町',
        43484: '熊本県津奈木町',
        43501: '熊本県錦町',
        43505: '熊本県多良木町',
        43506: '熊本県湯前町',
        43507: '熊本県水上村',
        43510: '熊本県相良村',
        43511: '熊本県五木村',
        43512: '熊本県山江村',
        43513: '熊本県球磨村',
        43514: '熊本県あさぎり町',
        43531: '熊本県苓北町',
        44000: '大分県',
        44201: '大分県大分市',
        44202: '大分県別府市',
        44203: '大分県中津市',
        44204: '大分県日田市',
        44205: '大分県佐伯市',
        44206: '大分県臼杵市',
        44207: '大分県津久見市',
        44208: '大分県竹田市',
        44209: '大分県豊後高田市',
        44210: '大分県杵築市',
        44211: '大分県宇佐市',
        44212: '大分県豊後大野市',
        44213: '大分県由布市',
        44214: '大分県国東市',
        44322: '大分県姫島村',
        44341: '大分県日出町',
        44461: '大分県九重町',
        44462: '大分県玖珠町',
        45000: '宮崎県',
        45201: '宮崎県宮崎市',
        45202: '宮崎県都城市',
        45203: '宮崎県延岡市',
        45204: '宮崎県日南市',
        45205: '宮崎県小林市',
        45206: '宮崎県日向市',
        45207: '宮崎県串間市',
        45208: '宮崎県西都市',
        45209: '宮崎県えびの市',
        45341: '宮崎県三股町',
        45361: '宮崎県高原町',
        45382: '宮崎県国富町',
        45383: '宮崎県綾町',
        45401: '宮崎県高鍋町',
        45402: '宮崎県新富町',
        45403: '宮崎県西米良村',
        45404: '宮崎県木城町',
        45405: '宮崎県川南町',
        45406: '宮崎県都農町',
        45421: '宮崎県門川町',
        45429: '宮崎県諸塚村',
        45430: '宮崎県椎葉村',
        45431: '宮崎県美郷町',
        45441: '宮崎県高千穂町',
        45442: '宮崎県日之影町',
        45443: '宮崎県五ヶ瀬町',
        46000: '鹿児島県',
        46201: '鹿児島県鹿児島市',
        46203: '鹿児島県鹿屋市',
        46204: '鹿児島県枕崎市',
        46206: '鹿児島県阿久根市',
        46208: '鹿児島県出水市',
        46210: '鹿児島県指宿市',
        46213: '鹿児島県西之表市',
        46214: '鹿児島県垂水市',
        46215: '鹿児島県薩摩川内市',
        46216: '鹿児島県日置市',
        46217: '鹿児島県曽於市',
        46218: '鹿児島県霧島市',
        46219: '鹿児島県いちき串木野市',
        46220: '鹿児島県南さつま市',
        46221: '鹿児島県志布志市',
        46222: '鹿児島県奄美市',
        46223: '鹿児島県南九州市',
        46224: '鹿児島県伊佐市',
        46225: '鹿児島県姶良市',
        46303: '鹿児島県三島村',
        46304: '鹿児島県十島村',
        46392: '鹿児島県さつま町',
        46404: '鹿児島県長島町',
        46452: '鹿児島県湧水町',
        46468: '鹿児島県大崎町',
        46482: '鹿児島県東串良町',
        46490: '鹿児島県錦江町',
        46491: '鹿児島県南大隅町',
        46492: '鹿児島県肝付町',
        46501: '鹿児島県中種子町',
        46502: '鹿児島県南種子町',
        46505: '鹿児島県屋久島町',
        46523: '鹿児島県大和村',
        46524: '鹿児島県宇検村',
        46525: '鹿児島県瀬戸内町',
        46527: '鹿児島県龍郷町',
        46529: '鹿児島県喜界町',
        46530: '鹿児島県徳之島町',
        46531: '鹿児島県天城町',
        46532: '鹿児島県伊仙町',
        46533: '鹿児島県和泊町',
        46534: '鹿児島県知名町',
        46535: '鹿児島県与論町',
        47000: '沖縄県',
        47201: '沖縄県那覇市',
        47205: '沖縄県宜野湾市',
        47207: '沖縄県石垣市',
        47208: '沖縄県浦添市',
        47209: '沖縄県名護市',
        47210: '沖縄県糸満市',
        47211: '沖縄県沖縄市',
        47212: '沖縄県豊見城市',
        47213: '沖縄県うるま市',
        47214: '沖縄県宮古島市',
        47215: '沖縄県南城市',
        47301: '沖縄県国頭村',
        47302: '沖縄県大宜味村',
        47303: '沖縄県東村',
        47306: '沖縄県今帰仁村',
        47308: '沖縄県本部町',
        47311: '沖縄県恩納村',
        47313: '沖縄県宜野座村',
        47314: '沖縄県金武町',
        47315: '沖縄県伊江村',
        47324: '沖縄県読谷村',
        47325: '沖縄県嘉手納町',
        47326: '沖縄県北谷町',
        47327: '沖縄県北中城村',
        47328: '沖縄県中城村',
        47329: '沖縄県西原町',
        47348: '沖縄県与那原町',
        47350: '沖縄県南風原町',
        47353: '沖縄県渡嘉敷村',
        47354: '沖縄県座間味村',
        47355: '沖縄県粟国村',
        47356: '沖縄県渡名喜村',
        47357: '沖縄県南大東村',
        47358: '沖縄県北大東村',
        47359: '沖縄県伊平屋村',
        47360: '沖縄県伊是名村',
        47361: '沖縄県久米島町',
        47362: '沖縄県八重瀬町',
        47375: '沖縄県多良間村',
        47381: '沖縄県竹富町',
        47382: '沖縄県与那国町',
    },
    undefined='市区町村(コード番号: %d)'
)
